<?php
class DeviceController extends ServerController {
	
	// 设备排序字段映射关系
	public $SortNameArr = array ('dev_name' => 'Dev_Name', // 设备名字
'session_type' => null, // 任务类型
'dev_description' => 'Dev_Description', // 物理位置
'state_syspower' => 'State_SysPower' ); // 状态
	

	/**
	 * 设备日志排序 字段
	 */
	public $LogSortNameArr = array ('datetime' => 'DateTime', // 日期或时间
'dev_name' => 'Dev_Name', // 设备
'event' => 'Event', // 事件
'user_name' => 'User_Name' ); // 用户
	

	/**
	 * *************************************************************************
	 */
	/**
	 * 获取设备分类 , web 和 app 采用相同的接口
	 * 组织成jquery easyui能识别的树结构。
	 * [{
	 * "id": 1,
	 * "text": "Node 1",
	 * "state": "closed",
	 * "children": [{
	 * "id": 11,
	 * "text": "Node 11"
	 * },{
	 * "id": 12,
	 * "text": "Node 12"
	 * }]
	 * },{
	 * "id": 2,
	 * "text": "Node 2",
	 * "state": "closed"
	 * }]
	 */
	public function actionListDeviceClasses() {
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		$DeviceSql = "SELECT Parent, COUNT(*) AS DeviceCount FROM DeviceList";
		if (! is_null ( $UserID ) && $UserID > 0) {
			$DeviceSql .= DeviceUtil::GetUserCtrDevSql ( " WHERE DevID ", $UserID );
		}
		$DeviceSql .= " GROUP BY Parent";
		$sql = "SELECT ClassID AS id,Name AS text, a.Parent, IF(ISNULL(DeviceCount), 0, DeviceCount) AS DeviceCount FROM DevClasses a 
			LEFT JOIN (" . $DeviceSql . ") b ON a.ClassID = b.Parent";
		$data = DBMethodUtils::listData ( $sql );
		$bta = new BuildTreeArray ( $data, 'id', 'Parent', 0 );
		$data = $bta->getTreeArray ();
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $data /*DeviceUtil::dealDeviceClassTree($data)*/ );
	}
	
	/**
	 * 获取设备信息，按照设备分类树形结构
	 */
	public function actionListDevicesForMember() {
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		$sql = 'SELECT DevID, Dev_Name, Parent FROM DeviceList';
		
		if (! is_null ( $UserID ) && $UserID > 0) {
			$sql .= DeviceUtil::GetUserCtrDevSql ( " WHERE DevID ", $UserID );
		}
		$sql .= " ORDER BY Dev_Name";
		$devices = DBMethodUtils::listData ( $sql );
		
		$sql = 'select ClassID as id,Name as text, Parent, 0 as IsDevice from DevClasses';
		$deviceClasses = DBMethodUtils::listData ( $sql );
		
		// 没有父节点的设备
		$NoParentDev = array ();
		// 有父节点的设备
		$HasParentDev = array ();
		
		// 设备按照父节点分类
		if (! is_null ( $devices )) {
			foreach ( $devices as $item ) {
				if (is_null ( $item ['Parent'] ) || ! is_numeric ( $item ['Parent'] )) {
					// 是根节点
					$NoParentDev [count ( $NoParentDev )] = array ('id' => $item ['DevID'], 'text' => $item ['Dev_Name'], 'Parent' => $item ['Parent'], 'IsDevice' => '1' );
				} else {
					// 不是根节点
					$param = null;
					if (isset ( $HasParentDev [$item ['Parent']] )) {
						$param = $HasParentDev [$item ['Parent']];
					}
					if (is_null ( $param )) {
						$param = array ();
					}
					$param [count ( $param )] = array ('id' => $item ['DevID'], 'text' => $item ['Dev_Name'], 'Parent' => $item ['Parent'], 'IsDevice' => '1' );
					$HasParentDev [$item ['Parent']] = $param;
				}
			}
		}
		// 设备分类处理
		$classArr = new BuildTreeArray ( $deviceClasses, 'id', 'Parent', 0 );
		$DeviceClassArr = $classArr->getTreeArray ();
		$DeviceClassArr = is_null ( $DeviceClassArr ) ? array () : $DeviceClassArr;
		$DeviceClassArr = DeviceUtil::PackDeviceTree ( $DeviceClassArr, $HasParentDev );
		$DeviceClassArr = is_null ( $DeviceClassArr ) ? array () : $DeviceClassArr;
		
		// 处理顶级设备
		foreach ( $NoParentDev as $item ) {
			$DeviceClassArr [count ( $DeviceClassArr )] = $item;
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', DeviceUtil::dealDeviceTree ( $DeviceClassArr ) );
	}
	
	/**
	 * 获取设备列表信息
	 */
	public function actionListDeviceList() {
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		
		$sql = 'SELECT a.DevID, a.Dev_Name, a.Parent, a.Dev_Description, a.Dev_Configuration, b.*, c.SessionName, c.StreamType
				FROM DeviceList a 
				LEFT JOIN DeviceStatus b ON a.DevID = b.DeviceID 
				LEFT JOIN PlaySessions c ON b.ActualSessionID=c.SessionID';
		$where = '';
		
		if (! is_null ( $UserID ) && $UserID > 0) {
			$where = DeviceUtil::GetUserCtrDevSql ( " WHERE a.DevID ", $UserID );
		}
		// 设备分类,1:中控，2：节点
		$DevType = 0;
		
		if (! empty ( $DataParam ['DevType'] )) {
			$DevType = $DataParam ['DevType'];
		}
		// 节点id
		if (isset ( $DataParam ['Parent'] ) && ! empty ( $DataParam ['Parent'] )) {
			$parent = $DataParam ['Parent'];
			$arr = explode ( ',', $parent );
			
			if (! is_null ( $arr ) && count ( $arr ) > 0) {
				$result = null;
				
				foreach ( $arr as $item ) {
					$ParentArr = DeviceUtil::LoadClassesId ( $item );
					
					if (! is_null ( $ParentArr ) && count ( $ParentArr ) > 0) {
						if (is_null ( $result )) {
							$result = $ParentArr;
						} else {
							foreach ( $ParentArr as $i ) {
								if (! in_array ( $i, $result )) {
									$result [count ( $result )] = $i;
								}
							}
						}
					}
				}
				
				if (! is_null ( $result )) {
					$res = "";
					foreach ( $result as $item ) {
						$res .= "," . $item;
					}
					$res = strlen ( $res ) > 0 ? substr ( $res, 1 ) : $res;
					
					if (! is_null ( $res ) && "" != trim ( $res )) {
						if (! is_null ( $where ) && "" != trim ( $where )) {
							$where .= " AND a.Parent IN(" . $res . ")";
						} else {
							$where = " WHERE a.Parent IN(" . $res . ")";
						}
					}
				}
			}
		}
		// 搜索关键字,按照名字搜索
		if (! empty ( $DataParam ['SearchKey'] )) {
			$SearchKey = $DataParam ['SearchKey'];
			
			if (! is_null ( $where ) && "" != trim ( $where )) {
				$where .= " AND Dev_Name like '%" . $SearchKey . "%'";
			} else {
				$where = " WHERE Dev_Name like '%" . $SearchKey . "%'";
			}
		}
		$sql .= $where;
		
		// 排序
		$HasOrder = false;
		
		if (! empty ( $DataParam ['SortName'] ) && ! empty ( $DataParam ['SortOrder'] )) {
			$SortName = $DataParam ['SortName'];
			$SortOrder = $DataParam ['SortOrder'];
			
			if (isset ( $this->SortNameArr [strtolower ( $SortName )] ) && ! is_null ( $this->SortNameArr [strtolower ( $SortName )] ) && ! is_null ( $SortOrder ) && isset ( $this->SortOrderArr [strtolower ( $SortOrder )] )) {
				$sql .= " ORDER BY " . $SortName . " " . $SortOrder;
				$HasOrder = true;
			}
		}
		
		if (! $HasOrder) {
			$sql .= " ORDER BY State_SysPower DESC";
		}
		
		// 分页数据
		if (isset ( $DataParam ['Start'] ) && isset ( $DataParam ['Size'] )) {
			$start = $DataParam ['Start'];
			$size = $DataParam ['Size'];
			
			if (is_numeric ( $start ) && is_numeric ( $size ) && $start >= 0 && $size > 0) {
				$sql = $sql . " LIMIT " . $start . "," . $size;
			}
		}
		// 查询数据
		$result = DBMethodUtils::listData ( $sql );
		// 查询扩展电源信息
		$expandSource = ExpandUtil::LoadExpandDev ();
		// 加载扩展电源的模式
		$expandMode = ExpandUtil::LoadExpandMode ();
		
		$arr = array ();
		if (! is_null ( $result )) {
			foreach ( $result as $item ) {
				$TempType = DeviceUtil::GetDevType ( $item ['DevID'] );
				
				if ($DevType == 1) {
					if (($TempType != DeviceUtil::DEV_TYPE_CENTRAL_BRD) && ($TempType != DeviceUtil::DEV_TYPE_CENTRAL_NON_BRD))
						continue;
				} else if ($DevType == 2) {
					if (($TempType != DeviceUtil::DEV_TYPE_BRD_DECODER) && ($TempType != DeviceUtil::DEV_TYPE_BRD_CABINET))
						continue;
				}
				$newitem = DeviceUtil::PackDevice ( $item, $expandSource, $expandMode, true );
				
				if (is_null ( $newitem ))
					continue;
				$arr [count ( $arr )] = $newitem;
			}
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $arr );
	}
	
	/**
	 * 获取在线离线设备数目
	 */
	public function actionLoadDevOnlineNum() {
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$Parent = - 1;
		
		if (isset ( $DataParam ['Parent'] ) && is_numeric ( $DataParam ['Parent'] )) {
			$Parent = $DataParam ['Parent'];
		}
		
		$sql = 'SELECT COUNT(*) AS AllCount FROM DeviceList';
		$Where = array ();
		
		if ($Parent > 0) { // 有父节点
			$Where [] = 'Parent IN(' . implode ( ',', DeviceUtil::LoadClassesId ( $Parent ) ) . ')';
		}
		if (! is_null ( $UserID ) && $UserID > 0) {
			$Where [] = DeviceUtil::GetUserCtrDevSql ( " DevID ", $UserID );
		}
		if (! empty ( $Where )) {
			$sql .= ' WHERE ' . implode ( ' AND ', $Where );
		}
		
		$AllCountData = DBMethodUtils::findData ( $sql );
		$AllCount = 0;
		
		if (! is_null ( $AllCountData ) && isset ( $AllCountData ['AllCount'] )) {
			$AllCount = $AllCountData ['AllCount'];
		}
		// 查询在线设备数目
		$sql = 'SELECT COUNT(*) AS OnlineCount FROM DeviceStatus';
		$Where = array ();
		
		if ($Parent > 0) { // 有父节点
			$Where [] = 'DeviceID IN(SELECT DevID FROM DeviceList WHERE Parent IN(' . implode ( ',', DeviceUtil::LoadClassesId ( $Parent ) ) . '))';
		}
		if (! is_null ( $UserID ) && $UserID > 0) {
			$Where [] = DeviceUtil::GetUserCtrDevSql ( " DeviceID ", $UserID );
		}
		if (! empty ( $Where )) {
			$sql .= ' WHERE ' . implode ( ' AND ', $Where );
		}
		$OnlineCountData = DBMethodUtils::findData ( $sql );
		$OnlineCount = 0;
		
		if (! is_null ( $OnlineCountData ) && isset ( $OnlineCountData ['OnlineCount'] )) {
			$OnlineCount = $OnlineCountData ['OnlineCount'];
		}
		
		if ($AllCount <= $OnlineCount) {
			$AllCount = $OnlineCount;
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', array ('OnlineCount' => ( int ) $OnlineCount, 'OfflineCount' => $AllCount - $OnlineCount ) );
	}
	
	/**
	 * 获取设备详细信息
	 */
	public function actionLoadDeviceDetail() {
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		if (empty ( $DataParam ['DevID'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$DEVICE_NO_DEV, '设备不存在，请确认！', null );
			return;
		}
		$DevID = $DataParam ['DevID'];
		$sql = 'SELECT a.DevID, a.Dev_Name, a.Parent, a.Dev_Description, a.Dev_Configuration, b.*, c.SessionName, c.StreamType FROM DeviceList a LEFT JOIN DeviceStatus b ON a.DevID = b.DeviceID 
				LEFT JOIN PlaySessions c ON b.ActualSessionID=c.SessionID WHERE a.DevID=' . $DevID;
		if (! is_null ( $UserID ) && $UserID > 0) {
			$sql .= DeviceUtil::GetUserCtrDevSql ( " AND a.DevID ", $UserID );
		}
		$model = DBMethodUtils::findData ( $sql );
		
		if (is_null ( $model )) {
			echo $this->PackResponseData ( ErrcodeUtil::$DEVICE_NO_DEV, '设备不存在，请确认！', null );
			return;
		}
		// 查询扩展电源信息
		$expandSource = ExpandUtil::LoadExpandDev ();
		// 加载扩展电源的模式
		$expandMode = ExpandUtil::LoadExpandMode ();
		
		$newmodel = DeviceUtil::PackDevice ( $model, $expandSource, $expandMode, false );
		
		if (! empty ( $newmodel ) && ! empty ( $model )) {
			$SteamTypeUp = round ( $model ['StreamType'] / 128 );
			$newmodel ['SteamTypeUp'] = $SteamTypeUp == 1 ? 1 : 0;
		}
		
		$RfDevice = ExpandUtil::LoadExpandDev ();
		$tempMap = array ();
		
		foreach ( $RfDevice as $item ) {
			$item ['Mode'] = 0;
			$item ['Mode_Desc'] = isset($expandMode[$item['Type']][$item ['Mode']]) ? $expandMode[$item['Type']][$item ['Mode']] : "";
			$item ['Local'] = 0;
			$tempMap [$item ['PwrID']] = $item;
		}
		//加载设备物联控制状态
		if (! empty ( $DevID )) {
			$devicsStatus = DBMethodUtils::findData ( 'SELECT * FROM DeviceDesiredStaus WHERE DeviceID = :DeviceID', array (':DeviceID' => $DevID ) );
			
			if (! empty ( $devicsStatus['RfDevCtrl'] )) {
				$RfDevStatus = $devicsStatus['RfDevCtrl'];
				//扩展设备信息
				$newexpandSource = array ();
				//状态模式列表
				$RfDevModeArr = array ();
				//
				$RfDevOnlieArr = array ();
				
				if (! is_null ( $RfDevStatus )) { //把状态拆分成16分
					$temp = bin2hex ( $RfDevStatus );
					
					$pos = 0;
					for($i = 0; $i < strlen ( $temp ) - 1; $i = $i + 2, $pos ++) {
						if (!isset($tempMap[$pos])) {
							continue;
						}
						$tempData = hexdec ( substr ( $temp, $i, 2 ) );
						$Mode = ($tempData & 0x07);
						$Type = $tempMap[$pos]['Type'];
						$tempMap[$pos] ['Mode'] = $Mode;
						$tempMap[$pos] ['Mode_Desc'] = $item ['Mode_Desc'] = isset($expandMode[$Type][$Mode]) ? $expandMode[$Type][$Mode] : "";
						$tempMap[$pos] ['Local'] = ($tempData & 0x10) > 0 ? 1 : 0;
					}
				}
			}
		}
		$newmodel ['RfDevStatus'] = array_values ( $tempMap );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $newmodel );
	}
	
	/**
	 * 设备批量控制，包括系统启用/禁用，系统开机/关机，投影仪开启/关闭,投影仪控制， 广播启用/禁用，扩展电源控制
	 */
	public function actionEditDeviceCtrl() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效,需要登陆
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		// 需要控制的设备id，格式1，2，3
		if (! isset ( $DataParam ['DeviceIDs'] ) || trim ( $DataParam ['DeviceIDs'] ) == '') {
			// 没有需要控制的设备
			echo $this->PackResponseData ( ErrcodeUtil::$DEVICE_NO_DEV, '请选择需要控制的设备后再操作，请确认！', null );
			return;
		}
		$devIds = $DataParam ['DeviceIDs'];
		//系统控制：0：关机，1：开机，2：禁用
		

		// 系统启用/禁用，0：禁用，1：启用（启用设置为关机）
		$sysStatus = - 1;
		
		if (isset ( $DataParam ['SysStatusNew'] ) && is_numeric ( $DataParam ['SysStatusNew'] ) && in_array ( $DataParam ['SysStatusNew'], array (0, 1, 2 ) )) {
			$sysStatus = $DataParam ['SysStatusNew'];
		} else {
			if (isset ( $DataParam ['SysStatus'] ) && is_numeric ( $DataParam ['SysStatus'] ) && in_array ( $DataParam ['SysStatus'], array (0, 1 ) )) {
				$sysStatus = $DataParam ['SysStatus'];
				
				if ($sysStatus == 0) { //禁用
					$sysStatus = 2;
				} else { //启用
					$sysStatus = 0;
				}
			}
			
			// 系统开机/关机命令，0：关机，1：开机
			$pwrStatus = - 1;
			
			if (isset ( $DataParam ['PwrStatus'] ) && is_numeric ( $DataParam ['PwrStatus'] ) && in_array ( $DataParam ['PwrStatus'], array (0, 1 ) )) {
				$pwrStatus = $DataParam ['PwrStatus'];
				
				if ($pwrStatus == 0) { //关机
					$sysStatus = 0;
				} else { //开机
					$sysStatus = 1;
				}
			}
		}
		// 投影仪源，1：计算机，2：笔记本，3：数字展台，4：视频
		$ProjectorSrc = - 1;
		
		if (isset ( $DataParam ['ProjectorSrc'] ) && is_numeric ( $DataParam ['ProjectorSrc'] )) {
			$ProjectorSrc = $DataParam ['ProjectorSrc'];
			
			if ($ProjectorSrc > 4 || $ProjectorSrc < 1) {
				$ProjectorSrc = - 1;
			}
		}
		// 投影仪开启/关闭,0：关闭，1：开启
		$projectorStatus = - 1;
		
		if (isset ( $DataParam ['ProjectorStatus'] ) && is_numeric ( $DataParam ['ProjectorStatus'] )) {
			$projectorStatus = $DataParam ['ProjectorStatus'];
			
			if ($projectorStatus != 1 && $projectorStatus != 0) {
				$projectorStatus = - 1;
			}
		}
		// 音量是否静音，0: 非静音，1：静音
		$VoiceMute = - 1;
		
		if (isset ( $DataParam ['VoiceMute'] ) && is_numeric ( $DataParam ['VoiceMute'] )) {
			$VoiceMute = $DataParam ['VoiceMute'];
			
			if ($VoiceMute != 1 && $VoiceMute != 0) {
				$VoiceMute = - 1;
			}
		}
		// 音量控制，0-63
		$VoiceValue = - 1;
		
		if (isset ( $DataParam ['VoiceValue'] ) && is_numeric ( $DataParam ['VoiceValue'] )) {
			$VoiceValue = $DataParam ['VoiceValue'];
			
			if ($VoiceValue < 0 || $VoiceValue > 63) {
				$VoiceValue = - 1;
			}
		}
		// 麦是否静音，0: 非静音，1：静音
		$MicMute = - 1;
		
		if (isset ( $DataParam ['MicMute'] ) && is_numeric ( $DataParam ['MicMute'] )) {
			$MicMute = $DataParam ['MicMute'];
			
			if ($MicMute != 1 && $MicMute != 0) {
				$MicMute = - 1;
			}
		}
		// 麦音量控制，0-63
		$MicValue = - 1;
		
		if (isset ( $DataParam ['MicValue'] ) && is_numeric ( $DataParam ['MicValue'] )) {
			$MicValue = $DataParam ['MicValue'];
			
			if ($MicValue < 0 || $MicValue > 63) {
				$MicValue = - 1;
			}
		}
		// 广播启用/禁用，0：禁用，1：启用
		$broadcastStatus = - 1;
		
		if (isset ( $DataParam ['BroadcastStatus'] ) && is_numeric ( $DataParam ['BroadcastStatus'] )) {
			$broadcastStatus = $DataParam ['BroadcastStatus'];
			
			if ($broadcastStatus != 1 && $broadcastStatus != 0) {
				$broadcastStatus = - 1;
			}
		}
		// 扩展电源控制,JSON数组，[{"PwrID":12,"Mode":0}] ，PwrID电源ID，Mode状态：0：关闭，1~4模式（其中电源1：打开电源，4：本地模式，其他无效）
		$expandInfo = null;
		
		if (isset ( $DataParam ['ExpandInfo'] )) {
			$expandInfo = CJSON::decode ( $DataParam ['ExpandInfo'] );
		}
		
		if ($sysStatus < 0 && $ProjectorSrc < 0 && $projectorStatus < 0 && $VoiceMute < 0 && $VoiceValue < 0 && $MicMute < 0 && $MicValue < 0 && $broadcastStatus < 0 && (is_null ( $expandInfo ) || count ( $expandInfo ) <= 0)) {
			// 没有需要修改的数据
			echo $this->PackResponseData ( ErrcodeUtil::$DEVICE_NO_CTRL, '设备控制无效，请确认！', null );
			return;
		}
		
		if ($sysStatus > 0 || $projectorStatus > 0) { // 需要判断控制权限
			if (! $this->JudgeDevCtrPrivaliege ( $UserID )) {
				echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有中控设备管理权限', null );
				return;
			}
		}
		
		if (! is_null ( $expandInfo ) && count ( $expandInfo ) > 0) { // 需要判断控制权限
			if (! $this->JudgeRfDevCtrPrivaliege ( $UserID )) {
				echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有物联设备管理权限', null );
				return;
			}
		}
		$sql = 'select dl.DevID as DeviceID,ds.IpAddress, ds.RfDevStatus from DeviceList dl LEFT join DeviceStatus ds on dl.DevID = ds.DeviceID WHERE 
			DevID IN(' . $devIds . ')';
		
		if (! is_null ( $UserID ) && $UserID > 0) {
			$sql .= DeviceUtil::GetUserCtrDevSql ( " AND DevID ", $UserID );
		}
		$devices = DBMethodUtils::listData ( $sql );
		
		if (is_null ( $devices ) || count ( $devices ) <= 0) { // 没有查找到需要修改的设备
			// 没有需要控制的设备
			echo $this->PackResponseData ( ErrcodeUtil::$DEVICE_OFFELINE, '不能控制离线的设备，请确认！', null );
			return;
		}
		
		foreach ( $devices as $item ) {
			if (in_array ( $sysStatus, array (0, 1, 2 ) )) { // 系统启用/禁用
				$CMD = 0x3E;
				DBMethodUtils::RunSql ( "call sp_send_dev_ctrl_cmd('" . $item ['DeviceID'] . "', '" . $item ['IpAddress'] . "', " . $CMD . ", " . $sysStatus . ",0,0, null)" );
			}
			//			if ($pwrStatus == 0 || $pwrStatus == 1) { // 系统开机/关机
			//				$CMD = 48;
			//				DBMethodUtils::RunSql ( "call sp_send_dev_ctrl_cmd('" . $item ['DeviceID'] . "', '" . $item ['IpAddress'] . "', " . $CMD . ", " . $pwrStatus . ",0,0, null)" );
			//			}
			if ($ProjectorSrc >= 1 && $ProjectorSrc <= 4) { // 投影仪源，1：计算机，2：笔记本，3：数字展台，4：视频
				$CMD = 51;
				DBMethodUtils::RunSql ( "call sp_send_dev_ctrl_cmd('" . $item ['DeviceID'] . "', '" . $item ['IpAddress'] . "', " . $CMD . ", " . $ProjectorSrc . ",0,0, null)" );
			}
			if ($projectorStatus == 0 || $projectorStatus == 1) { // 投影仪开启/关闭
				$CMD = 50;
				DBMethodUtils::RunSql ( "call sp_send_dev_ctrl_cmd('" . $item ['DeviceID'] . "', '" . $item ['IpAddress'] . "', " . $CMD . ", " . $projectorStatus . ",0,0, null)" );
			}
			if ($VoiceMute == 0 || $VoiceMute == 1) { // 音量是否静音，0: 非静音，1：静音
				$CMD = 53;
				DBMethodUtils::RunSql ( "call sp_send_dev_ctrl_cmd('" . $item ['DeviceID'] . "', '" . $item ['IpAddress'] . "', " . $CMD . ", " . $VoiceMute . ", 0, 0, null)" );
			}
			if ($VoiceValue >= 0 && $VoiceValue <= 63) { // 音量控制，0-63
				$CMD = 52;
				DBMethodUtils::RunSql ( "call sp_send_dev_ctrl_cmd('" . $item ['DeviceID'] . "', '" . $item ['IpAddress'] . "', " . $CMD . ", 0, " . $VoiceValue . " , 0, null)" );
			}
			if ($MicMute == 0 || $MicMute == 1) { // /麦是否静音，0: 非静音，1：静音
				$CMD = 60;
				DBMethodUtils::RunSql ( "call sp_send_dev_ctrl_cmd('" . $item ['DeviceID'] . "', '" . $item ['IpAddress'] . "', " . $CMD . ", " . $MicMute . ", 0, 0, null)" );
			}
			if ($MicValue >= 0 && $MicValue <= 63) { // 麦音量控制，0-63
				$CMD = 52;
				DBMethodUtils::RunSql ( "call sp_send_dev_ctrl_cmd('" . $item ['DeviceID'] . "', '" . $item ['IpAddress'] . "', " . $CMD . ", 1, " . $MicValue . " , 0, null)" );
			}
			if ($broadcastStatus == 0 || $broadcastStatus == 1) { // 广播启用/禁用
				$CMD = 58;
				DBMethodUtils::RunSql ( "call sp_send_dev_ctrl_cmd('" . $item ['DeviceID'] . "', '" . $item ['IpAddress'] . "', " . $CMD . ", " . $broadcastStatus . ",0,0, null)" );
			}
			if (! is_null ( $expandInfo ) && count ( $expandInfo ) > 0) { // 扩展电源控制,JSON数组，[{"PwrID":12,"Mode":0}] ，PwrID电源ID，Status状态：0：关闭，1~4模式（其中电源1：打开电源，4：本地模式，其他无效）
				

				// 状态模式列表
				$RfDevModeArr = array ();
				
				for($i = 0; $i < 16; $i ++) {
					$RfDevModeArr [] = str_pad ( '0', 2, '0', STR_PAD_LEFT );
				}
				$hasModify = false;
				
				foreach ( $expandInfo as $item1 ) {
					if (isset ( $item1 ["PwrID"] ) && isset ( $item1 ["Mode"] )) {
						$PwrID = $item1 ["PwrID"]; // 扩展设备ID
						$Mode = $item1 ["Mode"];
						$Local = isset ( $item1 ['Local'] ) && $item1 ['Local'] == 1 ? true : false;
						$Mode = $Mode <= 0 ? 0 : ($Mode >= 4 ? 4 : $Mode);
						$Mode = 0x08 | $Mode;
						
						if ($Local) {
							$Mode = $Mode | 0x10;
						}
						//						$Mode = $Mode + 8 + $Local; // 模式：0：关闭电源；电源：1：打开电源，4：本地模式，其他无效；空调：1~4对应空调4种模式
						$Mode = str_pad ( dechex ( $Mode ), 2, "0", STR_PAD_LEFT ); // 不足一个字节长度，自动前面补充0
						$RfDevModeArr [$PwrID] = str_pad ( $Mode, 2, '0', STR_PAD_LEFT );
						$hasModify = true;
					}
				}
				$res = implode ( '', $RfDevModeArr );
				
				$sql = 'update DeviceDesiredStaus set RfDevCtrl = func_update_rf_ctrl(DeviceID,  RfDevCtrl, 0x' . $res . ') where DeviceID = "' . $item ['DeviceID'] . '"';
				DBMethodUtils::RunSql ( $sql );
			}
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '操作成功！', null );
	}
	
	/**
	 * 日志查询
	 */
	public function actionListDeviceLogs() {
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		
		// 需要查询日志的设备ID，格式：1，2，3；查询全部日志则不传递参数
		$deviceID = "";
		
		if (isset ( $DataParam ['DeviceIDs'] )) {
			$deviceID = $DataParam ['DeviceIDs'];
		}
		// 日志开始时间,年月日；2015-12-24
		$beginTime = "";
		
		if (isset ( $DataParam ['BeginTime'] )) {
			$beginTime = $DataParam ['BeginTime'];
		}
		
		// 日志结束时间,年月日；2015-12-24
		$endTime = "";
		
		if (isset ( $DataParam ['EndTime'] )) {
			$endTime = $DataParam ['EndTime'];
		}
		
		if (is_null ( $endTime ) || is_null ( $beginTime ) || "" == trim ( $endTime ) || "" == trim ( $beginTime ) || $endTime < $beginTime) {
			echo $this->PackResponseData ( ErrcodeUtil::$DEVICE_ENDTIME_MUSTBIG, '结束时间必须大于开始时间，请确认！', null );
			return;
		}
		$beginTime = date ( 'Y-m-d', strtotime ( $beginTime ) ) . ' 00:00:00';
		$endTime = date ( 'Y-m-d', strtotime ( $endTime ) ) . ' 23:59:59';
		
		// 日志类型，格式：1，2，3；全部则不用传值
		if (empty ( $DataParam ['Event'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', array () );
			return;
		}
		$Event = $DataParam ['Event'];
		
		$sql = "SELECT a.DevLogID, a.DateTime, a.Event, a.State, a.CtrlUser, a.MsgContext, b.DevID, b.Dev_Name, c.User_Name, c.User_Desc FROM DeviceLog a ";
		$sql .= "left join DeviceList b on a.DeviceID=b.DevID left join Users c on a.CtrlUser = c.User_ID";
		$sql .= " WHERE DateTime >='" . $beginTime . "' AND DateTime<='" . $endTime . "'";
		
		if (! is_null ( $UserID ) && $UserID > 0) {
			$sql .= DeviceUtil::GetUserCtrDevSql ( " AND DeviceID ", $UserID );
		}
		
		if (! is_null ( $deviceID ) && "" != trim ( $deviceID )) {
			$sql = $sql . " AND DeviceID IN(" . $deviceID . ")";
		}
		
		if (! is_null ( $Event ) && "" != trim ( $Event )) {
			$sql = $sql . " AND Event IN(" . $Event . ")";
		}
		// 排序，DateTime：日期或时间，Dev_Name：设备，Event：事件，User_Name：用户
		if (isset ( $DataParam ['SortName'] ) && isset ( $DataParam ['SortOrder'] )) {
			if (isset ( $this->LogSortNameArr [strtolower ( $DataParam ['SortName'] )] ) && isset ( $this->SortOrderArr [strtolower ( $DataParam ['SortOrder'] )] )) {
				$sql .= ' ORDER BY ' . $this->LogSortNameArr [strtolower ( $DataParam ['SortName'] )] . ' ' . $this->SortOrderArr [strtolower ( $DataParam ['SortOrder'] )];
			}
		}
		
		// 分页数据
		if (isset ( $DataParam ['Start'] ) && isset ( $DataParam ['Size'] )) {
			$start = $DataParam ['Start'];
			$size = $DataParam ['Size'];
			
			if (is_numeric ( $start ) && is_numeric ( $size ) && $start >= 0 && $size > 0) {
				$sql = $sql . " LIMIT " . $start . "," . $size;
			}
		}
		$result = DBMethodUtils::listData ( $sql );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $result );
	}
	
	/**
	 * 导出日志
	 */
	public function actionExportDevLogs() {
		$UserID = $this->GetPostOwnerID ();
		
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		
		// 需要查询日志的设备ID，格式：1，2，3；查询全部日志则不传递参数
		$deviceID = "";
		
		if (isset ( $DataParam ['DeviceIDs'] )) {
			$deviceID = $DataParam ['DeviceIDs'];
		}
		// 日志开始时间,年月日；2015-12-24
		$beginTime = "";
		
		if (isset ( $DataParam ['BeginTime'] )) {
			$beginTime = $DataParam ['BeginTime'];
		}
		
		// 日志结束时间,年月日；2015-12-24
		$endTime = "";
		
		if (isset ( $DataParam ['EndTime'] )) {
			$endTime = $DataParam ['EndTime'];
		}
		
		if (is_null ( $endTime ) || is_null ( $beginTime ) || "" == trim ( $endTime ) || "" == trim ( $beginTime ) || $endTime < $beginTime) {
			echo $this->PackResponseData ( ErrcodeUtil::$DEVICE_ENDTIME_MUSTBIG, '结束时间必须大于开始时间，请确认！', null );
			return;
		}
		$beginTime = date ( 'Y-m-d', strtotime ( $beginTime ) ) . ' 00:00:00';
		$endTime = date ( 'Y-m-d', strtotime ( $endTime ) ) . ' 23:59:59';
		// 日志类型，格式：1，2，3；全部则不用传值
		if (empty ( $DataParam ['Event'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$DEVICE_NEED_EVENT, '', array () );
			return;
		}
		$Event = $DataParam ['Event'];
		
		$sql = "SELECT a.DevLogID, a.DateTime, a.Event, a.State, a.CtrlUser, a.MsgContext, b.DevID, b.Dev_Name, c.User_Name, c.User_Desc FROM DeviceLog a left join DeviceList b on a.DeviceID=b.DevID left join Users c on a.CtrlUser = c.User_ID";
		$sql = $sql . " WHERE DateTime >='" . $beginTime . "' AND DateTime<='" . $endTime . "'";
		
		if (! is_null ( $UserID ) && $UserID > 0) {
			$sql .= DeviceUtil::GetUserCtrDevSql ( " AND DeviceID ", $UserID );
		}
		
		if (! is_null ( $deviceID ) && "" != trim ( $deviceID )) {
			$sql = $sql . " AND DeviceID IN(" . $deviceID . ")";
		}
		
		if (! is_null ( $Event ) && "" != trim ( $Event )) {
			$sql = $sql . " AND Event IN(" . $Event . ")";
		}
		// 排序，DateTime：日期或时间，Dev_Name：设备，Event：事件，User_Name：用户
		if (isset ( $DataParam ['SortName'] ) && isset ( $DataParam ['SortOrder'] )) {
			if (isset ( $this->LogSortNameArr [strtolower ( $DataParam ['SortName'] )] ) && isset ( $this->SortOrderArr [strtolower ( $DataParam ['SortOrder'] )] )) {
				$sql .= ' ORDER BY ' . $this->LogSortNameArr [strtolower ( $DataParam ['SortName'] )] . ' ' . $this->SortOrderArr [strtolower ( $DataParam ['SortOrder'] )];
			}
		}
		
		// 分页数据
		if (isset ( $DataParam ['Start'] ) && isset ( $DataParam ['Size'] )) {
			$start = $DataParam ['Start'];
			$size = $DataParam ['Size'];
			
			if (is_numeric ( $start ) && is_numeric ( $size ) && $start >= 0 && $size > 0) {
				$sql = $sql . " LIMIT " . $start . "," . $size;
			}
		}
		$result = DBMethodUtils::listData ( $sql );
		
		$objectPHPExcel = Yii::app ()->yexcel->createPhpExcel ();
		$objectPHPExcel->setActiveSheetIndex ( 0 );
		
		// 数据的取出
		$model = Yii::app ()->session ['printdata'];
		
		// 表头的输出
		$objectPHPExcel->setActiveSheetIndex ( 0 )->setCellValue ( 'A1', '日期' );
		$objectPHPExcel->setActiveSheetIndex ( 0 )->setCellValue ( 'B1', '时间' );
		$objectPHPExcel->setActiveSheetIndex ( 0 )->setCellValue ( 'C1', '设备' );
		$objectPHPExcel->setActiveSheetIndex ( 0 )->setCellValue ( 'D1', '事件' );
		$objectPHPExcel->setActiveSheetIndex ( 0 )->setCellValue ( 'E1', '用户' );
		
		$i = 2;
		foreach ( $result as $item ) {
			$EventDesc = '';
			switch ($item ['Event']) {
				case 1 : // 在线/离线
					$EventDesc = $item ['State'] == 1 ? '上线' : '下线';
					break;
				case 2 : // 打开/关闭
					$EventDesc = $item ['State'] == 1 ? '开机' : '关机';
					break;
				case 3 : // 可用/不可用
					$EventDesc = $item ['State'] == 1 ? '启用' : '禁用';
					break;
				case 4 : // 投影机开/关
					$EventDesc = $item ['State'] == 1 ? '投影机开' : '投影机关';
					break;
				case 5 : // 紧急信息
					$EventDesc = '紧急信息';
					break;
				default :
					break;
			}
			
			$objectPHPExcel->setActiveSheetIndex ( 0 )->setCellValue ( 'A' . $i, date ( 'Y-m-d', strtotime ( $item ['DateTime'] ) ) );
			$objectPHPExcel->setActiveSheetIndex ( 0 )->setCellValue ( 'B' . $i, date ( 'H:i:s', strtotime ( $item ['DateTime'] ) ) );
			$objectPHPExcel->setActiveSheetIndex ( 0 )->setCellValue ( 'C' . $i, empty ( $item ['Dev_Name'] ) ? $item ['DeviceID'] : $item ['Dev_Name'] );
			$objectPHPExcel->setActiveSheetIndex ( 0 )->setCellValue ( 'D' . $i, $EventDesc );
			$objectPHPExcel->setActiveSheetIndex ( 0 )->setCellValue ( 'E' . $i, $item ['User_Name'] );
			$i ++;
		}
		ob_end_clean ();
		ob_start ();
		
		header ( 'Content-Type : application/vnd.ms-excel' );
		header ( 'Content-Disposition:attachment;filename="' . '设备日志-' . date ( "Y年m月j日" ) . '.xls"' );
		$objWriter = PHPExcel_IOFactory::createWriter ( $objectPHPExcel, 'Excel5' );
		$objWriter->save ( 'php://output' );
	}
	
	/**
	 * 能耗统计
	 */
	public function actionListDeviceStatistics() {
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		
		// 日志开始时间
		$beginTime = "";
		
		if (isset ( $DataParam ['BeginTime'] )) {
			$beginTime = $DataParam ['BeginTime'];
		}
		
		// 日志结束时间
		$endTime = "";
		
		if (isset ( $DataParam ['EndTime'] )) {
			$endTime = $DataParam ['EndTime'];
		}
		
		if (is_null ( $endTime ) || is_null ( $beginTime ) || "" == trim ( $endTime ) || "" == trim ( $beginTime ) || $endTime < $beginTime) {
			echo $this->PackResponseData ( ErrcodeUtil::$DEVICE_ENDTIME_MUSTBIG, '结束时间必须大于开始时间，请确认！', null );
			return;
		}
		$beginTime = date ( 'Y-m-d', strtotime ( $beginTime ) ) . ' 00:00:00';
		$endTime = date ( 'Y-m-d', strtotime ( $endTime ) ) . ' 23:59:59';
		
		$sql = "SELECT b.DevID, b.Dev_Name, a.StatisticDay, a.PowerConsumed,a.UsedTime FROM DeviceStatistic a LEFT JOIN DeviceList b ON a.DeviceID = b.DevID";
		$sql = $sql . " WHERE StatisticDay >='" . $beginTime . "' AND StatisticDay<='" . $endTime . "'";
		if (! is_null ( $UserID ) && $UserID > 0) {
			$sql .= DeviceUtil::GetUserCtrDevSql ( " AND DevID ", $UserID );
		}
		
		// 分页数据
		if (isset ( $DataParam ['Start'] ) && isset ( $DataParam ['Size'] )) {
			$start = $DataParam ['Start'];
			$size = $DataParam ['Size'];
			
			if (is_numeric ( $start ) && is_numeric ( $size ) && $start >= 0 && $size > 0) {
				$sql = $sql . " LIMIT " . $start . "," . $size;
			}
		}
		$result = DBMethodUtils::listData ( $sql );
		$res = array ();
		
		if (! is_null ( $result ) && count ( $result ) <= 0) {
			foreach ( $result as $item ) {
				$newitem = array ();
				$newitem ['DeviceID'] = $item ['DevID']; // 设备id
				$newitem ['Dev_Name'] = $item ['Dev_Name']; // 设备名字
				$newitem ['StatisticDay'] = $item ['StatisticDay']; // 统计日期，只有年月日的日期格式
				

				$PowerConsumed = bin2hex ( $item ['PowerConsumed'] ); // 32路能耗统计，每4个字节对应一个无符号32位的整数，0路表示中控整机;1路表示投影机;2～3 预留;4～5 空调控制器;6~7预留;8～31为电源控制器
				$UsedTime = bin2hex ( $item ['UsedTime'] ); // 32路时长统计，每4个字节对应一个无符号32位的整数，0路表示中控整机;1路表示投影机;2～3 预留;4～5 空调控制器;6~7预留;8～31为电源控制器
				

				$newitem ['device_pwr_0'] = hexdec ( ToolUtil::shr32 ( $PowerConsumed, 32 * 31 ) );
				$newitem ['device_pwr_1'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 1 ), 32 * 30 ) );
				$newitem ['device_pwr_2'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 2 ), 32 * 29 ) );
				$newitem ['device_pwr_3'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 3 ), 32 * 28 ) );
				$newitem ['device_pwr_4'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 4 ), 32 * 27 ) );
				$newitem ['device_pwr_5'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 5 ), 32 * 26 ) );
				$newitem ['device_pwr_6'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 6 ), 32 * 25 ) );
				$newitem ['device_pwr_7'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 7 ), 32 * 24 ) );
				$newitem ['device_pwr_8'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 8 ), 32 * 23 ) );
				$newitem ['device_pwr_9'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 9 ), 32 * 22 ) );
				$newitem ['device_pwr_10'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 10 ), 32 * 21 ) );
				$newitem ['device_pwr_11'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 11 ), 32 * 20 ) );
				$newitem ['device_pwr_12'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 12 ), 32 * 19 ) );
				$newitem ['device_pwr_13'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 13 ), 32 * 18 ) );
				$newitem ['device_pwr_14'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 14 ), 32 * 17 ) );
				$newitem ['device_pwr_15'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 15 ), 32 * 16 ) );
				$newitem ['device_pwr_16'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 16 ), 32 * 15 ) );
				$newitem ['device_pwr_17'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 17 ), 32 * 14 ) );
				$newitem ['device_pwr_18'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 18 ), 32 * 13 ) );
				$newitem ['device_pwr_19'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 19 ), 32 * 12 ) );
				$newitem ['device_pwr_20'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 20 ), 32 * 11 ) );
				$newitem ['device_pwr_21'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 21 ), 32 * 10 ) );
				$newitem ['device_pwr_22'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 22 ), 32 * 9 ) );
				$newitem ['device_pwr_23'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 23 ), 32 * 8 ) );
				$newitem ['device_pwr_24'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 24 ), 32 * 7 ) );
				$newitem ['device_pwr_25'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 25 ), 32 * 6 ) );
				$newitem ['device_pwr_26'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 26 ), 32 * 5 ) );
				$newitem ['device_pwr_27'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 27 ), 32 * 4 ) );
				$newitem ['device_pwr_28'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 28 ), 32 * 3 ) );
				$newitem ['device_pwr_29'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 29 ), 32 * 2 ) );
				$newitem ['device_pwr_30'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $PowerConsumed, 32 * 30 ), 32 * 1 ) );
				$newitem ['device_pwr_31'] = hexdec ( ToolUtil::shl32 ( $PowerConsumed, 32 * 31 ) );
				
				$newitem ['device_usetime_0'] = hexdec ( ToolUtil::shr32 ( $UsedTime, 32 * 31 ) );
				$newitem ['device_usetime_1'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 1 ), 32 * 30 ) );
				$newitem ['device_usetime_2'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 2 ), 32 * 29 ) );
				$newitem ['device_usetime_3'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 3 ), 32 * 28 ) );
				$newitem ['device_usetime_4'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 4 ), 32 * 27 ) );
				$newitem ['device_usetime_5'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 5 ), 32 * 26 ) );
				$newitem ['device_usetime_6'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 6 ), 32 * 25 ) );
				$newitem ['device_usetime_7'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 7 ), 32 * 24 ) );
				$newitem ['device_usetime_8'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 8 ), 32 * 23 ) );
				$newitem ['device_usetime_9'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 9 ), 32 * 22 ) );
				$newitem ['device_usetime_10'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 10 ), 32 * 21 ) );
				$newitem ['device_usetime_11'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 11 ), 32 * 20 ) );
				$newitem ['device_usetime_12'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 12 ), 32 * 19 ) );
				$newitem ['device_usetime_13'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 13 ), 32 * 18 ) );
				$newitem ['device_usetime_14'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 14 ), 32 * 17 ) );
				$newitem ['device_usetime_15'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 15 ), 32 * 16 ) );
				$newitem ['device_usetime_16'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 16 ), 32 * 15 ) );
				$newitem ['device_usetime_17'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 17 ), 32 * 14 ) );
				$newitem ['device_usetime_18'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 18 ), 32 * 13 ) );
				$newitem ['device_usetime_19'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 19 ), 32 * 12 ) );
				$newitem ['device_usetime_20'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 20 ), 32 * 11 ) );
				$newitem ['device_usetime_21'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 21 ), 32 * 10 ) );
				$newitem ['device_usetime_22'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 22 ), 32 * 9 ) );
				$newitem ['device_usetime_23'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 23 ), 32 * 8 ) );
				$newitem ['device_usetime_24'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 24 ), 32 * 7 ) );
				$newitem ['device_usetime_25'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 25 ), 32 * 6 ) );
				$newitem ['device_usetime_26'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 26 ), 32 * 5 ) );
				$newitem ['device_usetime_27'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 27 ), 32 * 4 ) );
				$newitem ['device_usetime_28'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 28 ), 32 * 3 ) );
				$newitem ['device_usetime_29'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 29 ), 32 * 2 ) );
				$newitem ['device_usetime_30'] = hexdec ( ToolUtil::shr32 ( ToolUtil::shl32 ( $UsedTime, 32 * 30 ), 32 * 1 ) );
				$newitem ['device_usetime_31'] = hexdec ( ToolUtil::shl32 ( $UsedTime, 32 * 31 ) );
				
				$res [count ( $res )] = $newitem;
			}
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $res );
	}
	
	/**
	 * 获取设备的任务列表
	 */
	public function actionListDeviceSessions() {
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		
		if (! isset ( $DataParam ['DeviceID'] ) || is_null ( $DataParam ['DeviceID'] ) || trim ( $DataParam ['DeviceID'] ) == '') {
			// 参数错误
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常，请确认！', null );
			return;
		}
        $specialDate = false;
		if(isset($DataParam['Date'])) {
			$date = explode('-', $DataParam['Date']);
			if(count($date) == 3 && checkdate($date[1], $date[2], $date[0])){
				 $begintime = $DataParam['Date'] . ' 00:00:00';
                 $endtime = $DataParam['Date'] . ' 23:59:59';
                 $specialDate = true;
			}
		}
        if($specialDate == false){
		    $begintime = date ( 'Y-m-d 00:00:00' );
		    $endtime = date ( "Y-m-d 23:59:59" );
        }
		$sql = 'call sp_get_dev_scheduled_tasks("' . $DataParam ['DeviceID'] . '", "' . $begintime . '", "' . $endtime . '")';
		$datas = DBMethodUtils::listData ( $sql );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $datas );
	}
	
	/**
	 * 删除设备
	 */
	public function actionDeleteDevices() {
		$UserID = $this->GetPostOwnerID ();
		
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		if (! isset ( $DataParam ['DeviceIDs'] ) || is_null ( $DataParam ['DeviceIDs'] ) || trim ( $DataParam ['DeviceIDs'] ) == '') {
			// 参数错误
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常，请确认！', null );
			return;
		}
		$sql = 'SELECT * FROM DeviceList WHERE DevID IN (' . $DataParam ['DeviceIDs'] . ') AND DevID NOT IN(SELECT DeviceID FROM DeviceStatus)';
		
		if (! is_null ( $UserID ) && $UserID > 0) {
			$sql .= DeviceUtil::GetUserCtrDevSql ( " AND DevID ", $UserID );
		}
		$arr = DBMethodUtils::listData ( $sql );
		
		if (is_null ( $arr ) || count ( $arr ) <= 0) {
			echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '删除成功', null );
			return;
		}
		foreach ( $arr as $item ) {
			if (! isset ( $item ['DevID'] )) {
				continue;
			}
			// 删除设备
			$sql = 'call sp_delete_device("' . $item ['DevID'] . '")';
			DBMethodUtils::RunSql ( $sql );
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '删除成功', null );
	}
	
	/**
	 * 拷贝设备
	 */
	public function actionCopyDevice() {
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		
		if (! isset ( $DataParam ['SrcDevice'] ) || is_null ( $DataParam ['SrcDevice'] ) || trim ( $DataParam ['SrcDevice'] ) == '' || ! isset ( $DataParam ['DstDevice'] ) || is_null ( $DataParam ['DstDevice'] ) || trim ( $DataParam ['DstDevice'] ) == '') {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数遗异常', null );
			return;
		}
		if (! isset ( $DataParam ['NameFlag'] ) || ! is_numeric ( $DataParam ['NameFlag'] ) || ! isset ( $DataParam ['ConfigFlag'] ) || ! is_numeric ( $DataParam ['ConfigFlag'] ) || ! isset ( $DataParam ['TaskFlag'] ) || ! is_numeric ( $DataParam ['TaskFlag'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数遗异常', null );
			return;
		}
		// 目的设备ID
		$DstArr = explode ( ',', $DataParam ['DstDevice'] );
		
		if (is_null ( $DstArr ) || count ( $DstArr ) <= 0) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数遗异常', null );
			return;
		}
		// 源设备ID
		$SrcDeviceID = $DataParam ['SrcDevice'];
		
		// 拷贝内容掩码
		$OptionMask = 0;
		$OptionMask = $DataParam ['NameFlag'] == 1 ? $OptionMask | 0X0A : $OptionMask & 0XF5;
		$OptionMask = $DataParam ['ConfigFlag'] == 1 ? $OptionMask | 0X01 : $OptionMask & 0XFE;
		$OptionMask = $DataParam ['TaskFlag'] == 1 ? $OptionMask | 0X04 : $OptionMask & 0XFB;
		
		// 校验源设备是否存在
		$sql = 'SELECT * FROM DeviceList a LEFT JOIN DeviceStatus b ON a.DevID = b.DeviceID WHERE DevID = "' . $SrcDeviceID . '"';
		$SrcDevice = DBMethodUtils::findData ( $sql );
		
		if (is_null ( $SrcDevice ) || ! isset ( $SrcDevice ['DevID'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$DEVICE_NO_DEV, '源设备不存在', null );
			return;
		}
		if (count ( $DstArr ) == 1 && (! isset ( $SrcDevice ['State_SysPower'] ) || is_null ( $SrcDevice ['State_SysPower'] ))) {
			if ($OptionMask & 0X0F == 0X0F) {
				$OptionMask = 0X8F;
			}
		}
		// 获取源设备类型
		$SrcType = DeviceUtil::GetDevType ( $SrcDeviceID );
		try {
			foreach ( $DstArr as $item ) {
				if (is_null ( $item ) || trim ( $item ) == '') {
					continue;
				}
				$CopyOptionMask = $OptionMask;
				// 获取目的设备类型
				$DstType = DeviceUtil::GetDevType ( $item );
				
				if ($DstType == DeviceUtil::DEV_TYPE_GROUP) {
					continue;
				}
				if ($DstType != $SrcType) {
					$CopyOptionMask = $CopyOptionMask & 0XFB;
				}
				
				if ($CopyOptionMask > 0) { // 拷贝设备信息
					// TODO
					$sql = 'SELECT func_dulicate_device("' . $SrcDeviceID . '", "' . $item . '", ' . $CopyOptionMask . ')';
					DBMethodUtils::RunSql ( $sql );
				}
			}
		} catch ( Exception $e ) {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '拷贝失败', null );
			return;
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '拷贝成功', null );
	}
	
	/**
	 * 加载设备配置信息
	 */
	public function actionLoadDeviceConfig() {
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		
		if (! isset ( $DataParam ['DeviceID'] ) || trim ( $DataParam ['DeviceID'] ) == '') {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		// 设备ID
		$DeviceID = $DataParam ['DeviceID'];
		// DevCameraConfig
		$sql = 'SELECT CameraIpAddr, CameraPort, CameraUser, CameraPasswd FROM DeviceList WHERE DevID ="' . $DeviceID . '"';
		$DevCameraConfig = DBMethodUtils::findData ( $sql );
		
		// DevConfig
		$sql = 'SELECT DeviceList.Dev_Configuration, DeviceStatus.IpAddress FROM DeviceList 
			LEFT JOIN DeviceStatus ON DeviceList.DevID = DeviceStatus.DeviceID WHERE DeviceList.DevID="' . $DeviceID . '"';
		$TempDevConfig = DBMethodUtils::findData ( $sql );
		
		$DevConfig = new DevConfig ();
		$DevConfig ['DevID'] = $DeviceID;
		
		if (! is_null ( $TempDevConfig ) && isset ( $TempDevConfig ['Dev_Configuration'] )) {
			$DevConfig ['IpAddress'] = $TempDevConfig ['IpAddress'];
			// 解析配置数据
			$DevConfig->Parse ( $TempDevConfig ['Dev_Configuration'] );
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', array ('DevCameraConfig' => $DevCameraConfig, 'DevConfig' => $DevConfig ) );
	}
	
	/**
	 * 更新设备配置信息
	 */
	public function actionUpdateDeviceConfig() {
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		
		if (empty ( $DataParam ['DevCameraConfig'] ) || empty ( $DataParam ['DevConfig'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DevConfig = new DevConfig ();
		$CameraConfig = new DevCameraConfig ();
		
		if (! $DevConfig->ParseFromJson ( $DataParam ['DevConfig'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		
		// 更新设备配置
		$configStr = strtoupper ( $DevConfig->ToStr () );
		$sql = "call sp_send_dev_cfg_cmd('" . $DevConfig->DevID . "', '" . $DevConfig->IpAddress . "' , '" . $configStr . "');";
		DBMethodUtils::RunSql ( $sql );
		
		// 更新监控
		$Ipaddr = null;
		$User = null;
		$Passwd = null;
		$Port = null;
		
		if ($CameraConfig->ParseFromJson ( $DataParam ['DevCameraConfig'] )) {
			$Ipaddr = $CameraConfig->Ipaddress;
			$User = $CameraConfig->User;
			$Passwd = $CameraConfig->Passwd;
			$Port = $CameraConfig->Port;
		}
		$sql = 'update DeviceList set CameraIpAddr = "' . $Ipaddr . '", CameraPort = "' . $Port . '", CameraUser = "' . $User . '", CameraPasswd = "' . $Passwd . '" Where DevID = "' . $DevConfig->DevID . '";';
		DBMethodUtils::RunSql ( $sql );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '修改成功', null );
	}
	
	/**
	 * 设置Ip
	 */
	public function actionUpdateIp() {
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		// 设备ID
		if (empty ( $DataParam ['DeviceID'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		
		// 是否是动态Ip, 1:动态Ip，0：静态Ip
		if (! isset ( $DataParam ['IsDynamic'] ) || ! is_numeric ( $DataParam ['IsDynamic'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$IsDynamic = $DataParam ['IsDynamic'];
		$DeviceStatus = DBMethodUtils::findData ( 'SELECT * FROM DeviceStatus WHERE DeviceID="' . $DataParam ['DeviceID'] . '"' );
		
		if (is_null ( $DeviceStatus ) || ! isset ( $DeviceStatus ['IpAddress'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$DEVICE_OFFELINE, '设备不在线', null );
			return;
		}
		
		if ($IsDynamic == 0) { // 静态Ip
			if (empty ( $DataParam ['Ip'] ) || empty ( $DataParam ['Mask'] ) || empty ( $DataParam ['Getway'] )) {
				echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
				return;
			}
			$Ip = trim ( $DataParam ['Ip'] );
			$Mask = trim ( $DataParam ['Mask'] );
			$Getway = trim ( $DataParam ['Getway'] );
			
			if ($Ip != filter_var ( $Ip, FILTER_VALIDATE_IP ) || $Mask != filter_var ( $Mask, FILTER_VALIDATE_IP ) || $Getway != filter_var ( $Getway, FILTER_VALIDATE_IP )) {
				echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
				return;
			}
			// Ip转换
			$newIp = bindec ( decbin ( ip2long ( $Ip ) ) );
			$newMask = bindec ( decbin ( ip2long ( $Mask ) ) );
			$newGetway = bindec ( decbin ( ip2long ( $Getway ) ) );
			
			// 设置Ip
			$CMD = 63;
			$sql = 'call sp_send_dev_ctrl_cmd("' . $DeviceStatus ['DeviceID'] . '", "' . $DeviceStatus ['IpAddress'] . '", ' . $CMD . ', ' . $newIp . ',' . $newMask . ',' . $newGetway . ', null);';
			try {
				DBMethodUtils::RunSql ( $sql );
				
				echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '设置成功', null );
				return;
			} catch ( Exception $e ) {
				
				echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '设置失败', null );
				return;
			}
		} else if ($IsDynamic == 1) { // 动态Ip
			$newIp = 0;
			$newMask = 0;
			$newGetway = 0;
			// 设置Ip
			$CMD = 63;
			$sql = 'call sp_send_dev_ctrl_cmd("' . $DeviceStatus ['DeviceID'] . '", "' . $DeviceStatus ['IpAddress'] . '", ' . $CMD . ', ' . $newIp . ',' . $newMask . ',' . $newGetway . ', null);';
			
			try {
				DBMethodUtils::RunSql ( $sql );
				
				echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '设置成功', null );
				return;
			} catch ( Exception $e ) {
				
				echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '设置失败', null );
				return;
			}
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
		return;
	}
	
	/******************************************only for web******************************************/
	/**
	 * 获取设备树形列表信息
	 */
	public function actionListDeviceTree() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$sql = 'select a.DevID,a.Dev_Name,a.Dev_Description,b.*,e.SessionID,c.SessionName, d.ModeName
			, a.Parent, c.StreamType from DeviceList a LEFT JOIN DeviceStatus b on a.DevID = b.DeviceID LEFT JOIN PlaySessions c on c.SessionID=b.ActualSessionID 
			left join DeviceDesiredStaus e on e.DeviceID = a.DevID 
			LEFT JOIN BroadcastMode d on d.idBroadcastMode = e.BrdMode 
			where sp_dev_belong_group( a.DevID , 0) = true';
		//		$sql = 'SELECT a.DevID, a.Dev_Name, a.Parent, a.Dev_Description, a.Dev_Configuration, b.*, c.SessionName FROM DeviceList a LEFT JOIN DeviceStatus b ON a.DevID = b.DeviceID 
		//				LEFT JOIN PlaySessions c ON b.ActualSessionID=c.SessionID';
		$where = array ();
		
		if (! is_null ( $UserID ) && $UserID > 0) {
			$where [] = DeviceUtil::GetUserCtrDevSql ( " a.DevID ", $UserID );
		}
		// 设备分类,1:中控，2：节点
		$DevType = 0;
		
		if (! empty ( $DataParam ['DevType'] )) {
			$DevType = $DataParam ['DevType'];
		}
		$parent = 0;
		$HadParentArr = array ();
		
		// 节点id
		if (isset ( $DataParam ['Parent'] ) && ! empty ( $DataParam ['Parent'] )) {
			$parent = $DataParam ['Parent'];
			$arr = explode ( ',', $parent );
			
			if (! empty ( $arr )) {
				foreach ( $arr as $item ) {
					if (empty ( $item ) || $item <= 0) {
						continue;
					}
					$ParentArr = DeviceUtil::LoadClassesId ( $item );
					
					if (! empty ( $ParentArr )) {
						$HadParentArr = array_merge ( $HadParentArr, $ParentArr );
					}
					
					if (! empty ( $HadParentArr )) {
						$where [] = " a.Parent IN(" . implode ( ',', $HadParentArr ) . ")";
					}
				}
			}
		}
		// 搜索关键字,按照名字搜索
		if (! empty ( $DataParam ['SearchKey'] )) {
			$SearchKey = $DataParam ['SearchKey'];
			$where [] = " Dev_Name like '%" . $SearchKey . "%'";
		}
		if ($DevType == 1) { //中控
			$where [] = ' (LEFT(DevID, 1) = "0" OR LEFT(DevID, 1) = "2")';
		} else if ($DevType == 2) { //节点
			$where [] = ' LEFT(DevID, 1) = "4"';
		}
		
		if (! empty ( $where )) {
			$sql .= ' AND ' . implode ( ' AND ', $where );
		}
		//获取设备总数
		$CountSql = "SELECT COUNT(*) c FROM (" . $sql . ") cc";
		$AllCount = 0;
		$AllCountData = DBMethodUtils::findData ( $CountSql );
		
		if (! empty ( $AllCountData ['c'] )) {
			$AllCount = $AllCountData ['c'];
		}
		//获取设备在线
		$OnlineSql = "SELECT COUNT(*) c FROM DeviceStatus WHERE DeviceID IN(SELECT DevID FROM (" . $sql . ") cc";
		$OnlineSql .= ")";
		$OnlineCount = 0;
		$OnlineCountData = DBMethodUtils::findData ( $OnlineSql );
		
		if (! empty ( $OnlineCountData ['c'] )) {
			$OnlineCount = $OnlineCountData ['c'];
		}
		//离线设备数目
		$OfflineCount = $AllCount > $OnlineCount ? $AllCount - $OnlineCount : 0;
		
		// 排序
		$SortFlag = false;
		
		if (! empty ( $_POST ['sort'] ) && ! empty ( $_POST ['order'] )) {
			$Sort = $_POST ['sort'];
			$Order = $_POST ['order'];
			
			//可排序的字段
			$SortCol = array ("Dev_Name", "Dev_Description", "SessionName", "State_SysPower", "State_ProjectorStatus", "State_ProjectorLampStatus", "State_ExDevice1Status", "State_ExDevice2Status" );
			
			if ($Sort == "text") {
				$Sort = "Dev_Name";
			} else if ($Sort == "State_Online") {
				$Sort = "State_SysPower";
			} else if (! in_array ( $Sort, $SortCol )) {
				$Sssql = "SELECT * FROM PwrDisplaySet WHERE Name='" . $Sort . "'";
				$tempdata = DBMethodUtils::findData ( $Sssql );
				
				if (! empty ( $tempdata )) {
					$Sort = "RfDevStatus";
				}
			}
			$SortCol [] = "RfDevStatus";
			
			if (in_array ( strtolower ( $Order ), array ('asc', 'desc' ) ) && in_array ( $Sort, $SortCol )) {
				$sql .= " ORDER BY " . $Sort . " " . $Order;
				$SortFlag = true;
			}
		}
		
		if (! $SortFlag) {
			$sql .= " ORDER BY State_SysPower DESC, Dev_Name";
		}
		
		//分页数据
		if (isset ( $_POST ['page'] ) && isset ( $_POST ['rows'] ) && is_numeric ( $_POST ['page'] ) && is_numeric ( $_POST ['rows'] )) {
			$page = $_POST ['page'];
			$size = $_POST ['rows'];
			$start = ($page - 1) * $size;
			$sql = $sql . " LIMIT " . $start . "," . $size;
		}
		// 返回数据类型，1：列表；2：树形结构
		$DataType = 2;
		
		if (! empty ( $DataParam ['DataType'] )) {
			$DataType = $DataParam ['DataType'];
			
			if (! in_array ( $DataType, array (1, 2 ) )) {
				$DataType = 2;
			}
		}
		$devices = DBMethodUtils::listData ( $sql );
		
		// 查询扩展电源信息
		$expandSource = ExpandUtil::LoadExpandDev ();
		// 加载扩展电源的模式
		$expandMode = ExpandUtil::LoadExpandMode ();
		
		if ($DataType == 1) { // 列表
			$DeviceClassArr = array ();
			
			// 设备按照父节点分类
			if (! empty ( $devices )) {
				foreach ( $devices as $row ) {
					$TempType = DeviceUtil::GetDevType ( $row ['DevID'] );
					
					if ($DevType == 1) {
						if (($TempType != DeviceUtil::DEV_TYPE_CENTRAL_BRD) && ($TempType != DeviceUtil::DEV_TYPE_CENTRAL_NON_BRD))
							continue;
					} else if ($DevType == 2) {
						if (($TempType != DeviceUtil::DEV_TYPE_BRD_DECODER) && ($TempType != DeviceUtil::DEV_TYPE_BRD_CABINET))
							continue;
					}
					$item = DeviceUtil::PackDevice ( $row, $expandSource, $expandMode, false );
					$SteamTypeUp = round ( $row ['StreamType'] / 128 );
					$item ['SteamTypeUp'] = $SteamTypeUp == 1 ? 1 : 0;
					$item ['IsCtrl'] = 1;
					
					if (($TempType != DeviceUtil::DEV_TYPE_CENTRAL_BRD) && ($TempType != DeviceUtil::DEV_TYPE_CENTRAL_NON_BRD)) { //节点
						$item ['IsCtrl'] = 0;
					} else if (($TempType != DeviceUtil::DEV_TYPE_BRD_DECODER) && ($TempType != DeviceUtil::DEV_TYPE_BRD_CABINET)) { //中控
						$item ['IsCtrl'] = 1;
					}
					$item ['id'] = $item ['DevID'];
					$item ['text'] = $item ['Dev_Name'];
					$item ['isDevice'] = 1;
					
					//					unset ( $item ['DevID'] );
					//					unset ( $item ['Dev_Name'] );
					

					if (is_null ( $item )) {
						continue;
					}
					$DeviceClassArr [] = $item;
				}
			}
			
			echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', array ('Total' => $AllCount, 'Rows' => $DeviceClassArr, 'Online' => $OnlineCount, 'Offline' => $OfflineCount ) );
			return;
		} else { // 树形结构
			// 没有父节点的设备
			$NoParentDev = array ();
			// 有父节点的设备
			$HasParentDev = array ();
			// 分类ID
			$HasChildClass = array ();
			
			// 设备按照父节点分类
			if (! empty ( $devices )) {
				foreach ( $devices as $row ) {
					$TempType = DeviceUtil::GetDevType ( $row ['DevID'] );
					
					if ($DevType == 1) {
						if (($TempType != DeviceUtil::DEV_TYPE_CENTRAL_BRD) && ($TempType != DeviceUtil::DEV_TYPE_CENTRAL_NON_BRD))
							continue;
					} else if ($DevType == 2) {
						if (($TempType != DeviceUtil::DEV_TYPE_BRD_DECODER) && ($TempType != DeviceUtil::DEV_TYPE_BRD_CABINET))
							continue;
					}
					$item = DeviceUtil::PackDevice ( $row, $expandSource, $expandMode, false );
					$item ['IsCtrl'] = 1;
					
					if (($TempType != DeviceUtil::DEV_TYPE_CENTRAL_BRD) && ($TempType != DeviceUtil::DEV_TYPE_CENTRAL_NON_BRD)) { //节点
						$item ['IsCtrl'] = 0;
					} else if (($TempType != DeviceUtil::DEV_TYPE_BRD_DECODER) && ($TempType != DeviceUtil::DEV_TYPE_BRD_CABINET)) { //中控
						$item ['IsCtrl'] = 1;
					}
					$item ['id'] = $item ['DevID'];
					$item ['text'] = $item ['Dev_Name'];
					$item ['isDevice'] = 1;
					
					unset ( $item ['DevID'] );
					unset ( $item ['Dev_Name'] );
					
					if (is_null ( $item )) {
						continue;
					}
					if (is_null ( $item ['Parent'] ) || ! is_numeric ( $item ['Parent'] ) || $item ['Parent'] == $parent) {
						// 是根节点
						$NoParentDev [] = $item;
					} else {
						// 不是根节点
						$param = null;
						if (isset ( $HasParentDev [$item ['Parent']] )) {
							$param = $HasParentDev [$item ['Parent']];
						}
						if (is_null ( $param )) {
							$param = array ();
						}
						$param [count ( $param )] = $item;
						$HasParentDev [$item ['Parent']] = $param;
						
						if (! in_array ( $item ['Parent'], $HasChildClass )) {
							$HasChildClass [] = $item ['Parent'];
						}
					}
				}
			}
			// 获取设备分类信息
			$sql = 'select ClassID as id,Name as text, IF(Parent = ' . $parent . ', NULL,  Parent) Parent, 0 as IsDevice from DevClasses';
			
			if (! empty ( $HadParentArr )) {
				$sql .= " WHERE Parent IN(" . implode ( ',', $HadParentArr ) . ")";
			}
			$deviceClasses = DBMethodUtils::listData ( $sql );
			
			// 设备分类处理
			$classArr = new BuildTreeArray ( $deviceClasses, 'id', 'Parent', 0 );
			$DeviceClassArr = $classArr->getTreeArray ();
			$DeviceClassArr = is_null ( $DeviceClassArr ) ? array () : $DeviceClassArr;
			$DeviceClassArr = DeviceUtil::PackDeviceTree ( $DeviceClassArr, $HasParentDev );
			$DeviceClassArr = is_null ( $DeviceClassArr ) ? array () : $DeviceClassArr;
			
			// 处理顶级设备
			foreach ( $NoParentDev as $item ) {
				$DeviceClassArr [count ( $DeviceClassArr )] = $item;
			}
			
			echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', array ('Total' => $AllCount, 'Rows' => $DeviceClassArr, 'Online' => $OnlineCount, 'Offline' => $OfflineCount ) );
			return;
		}
	}
	
	/**
	 * 获取分类路径
	 */
	public function actionListDevPath() {
		
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DevID = '';
		if (isset ( $DataParam ['DevID'] )) {
			$DevID = $DataParam ['DevID'];
		}
		$Device = DBMethodUtils::findData ( 'SELECT * FROM DeviceList WHERE DevID="' . $DevID . '"' );
		$res = array (array ('id' => 0, 'isClass' => '1', 'name' => $this->getStr ( 'appcommon', 'all_category' ) ) );
		
		if (! empty ( $Device )) {
			$Parent = $Device ['Parent'];
			$Name = $Device ['Dev_Name'];
			//获取分类路径
			$temparr = array ();
			$data = DeviceUtil::LoadDevClass ( $Parent );
			
			while ( ! empty ( $data ) ) {
				$temparr [] = $data;
				$data = DeviceUtil::LoadDevClass ( $data ['Parent'] );
			}
			
			if (count ( $temparr ) > 0) {
				for($i = count ( $temparr ) - 1; $i >= 0; $i --) {
					$res [] = array ('id' => $temparr [$i] ['ClassID'], 'isClass' => '1', 'name' => $temparr [$i] ['Name'] );
				}
			}
			$res [] = array ('id' => - 1, 'isClass' => '0', 'name' => $Name );
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $res );
	}
	
	/**
	 * 获取分类路径
	 */
	public function actionListDevClassParent() {
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$ClassId = 0;
		
		if (isset ( $DataParam ['ClassID'] ) && is_numeric ( $DataParam ['ClassID'] )) {
			$ClassId = $DataParam ['ClassID'];
		}
		$temparr = array ();
		$data = DeviceUtil::LoadDevClass ( $ClassId );
		
		while ( ! is_null ( $data ) ) {
			$temparr [] = $data;
			$data = DeviceUtil::LoadDevClass ( $data ['Parent'] );
		}
		$res = array (array ('id' => 0, 'name' => $this->getStr ( 'appcommon', 'all_category' ) ) );
		
		if (count ( $temparr ) > 0) {
			for($i = count ( $temparr ) - 1; $i >= 0; $i --) {
				$res [] = array ('id' => $temparr [$i] ['ClassID'], 'name' => $temparr [$i] ['Name'] );
			}
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $res );
	}
}
