<?php
/***************************************************
 * 模块定义:
 * 定义媒体管理部分的API
 **************************************************/
class MediaController extends ServerController {
	
	//文件类型
	const MediaImageIndexCelt = 0; //音频
	const MediaImageIndexAudio = 1; //音频（暂时不知和0的区别）
	const MediaImageIndexVedio = 2; //视频
	const MediaImageIndexUrl = 3; //节目源
	const MediaImageIndexGroup = 4; //文件夹
	

	/**
	 * 获取媒体树 
	 */
	public function actionListMediaTree() {
		
		//获取用户
		$UserID = $this->GetPostOwnerID ();
		
		if (is_null ( $UserID ) || $UserID == 0) { //超级管理员
			$sql = "select MediaID as id, FileName as text, Parent, 'closed' AS state from MediaFiles where TotalTime = 0";
			
			if (! is_null ( $UserID ) && $UserID > 0) {
				$sql .= ' AND Owner=' . $UserID;
			}
			$result = DBMethodUtils::listData ( $sql );
			
			if (is_null ( $result ) || count ( $result ) <= 0) {
				echo "";
				return;
			}
			$bta = new BuildTreeArray ( $result, 'id', 'Parent', 0 );
			$data = $bta->getTreeArray ();
			
			echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $data );
		} else if ($UserID > 0) { //普通用户
			$Sql = 'SELECT MediaID as id, FileName as text, Parent, "closed" AS state FROM MediaFiles WHERE TotalTime = 0 AND Owner="' . $UserID . '"';
			$Sql .= ' AND Parent IN (SELECT MIN(Parent) FROM MediaFiles WHERE TotalTime = 0 AND Owner="' . $UserID . '")';
			$Res = DBMethodUtils::listData ( $Sql );
			
			if (empty ( $Res )) {
				$Res = array ();
			}
			$OutRes = array ();
			
			foreach ( $Res as $key => $Item ) {
				$tempArr = AMediaUtil::LoadChildren ( $Item ['id'], self::MENU_TYPE_USER );
				
				if (! empty ( $tempArr )) {
					$OutRes = array_merge ( $OutRes, $tempArr );
				}
			}
			$Res = $OutRes;
			
			echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $Res );
		} else { //说明是登录用户，没有树
			echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', array () );
			return;
		}
	}

	/**
	 * 获取媒体资源文件
	 */
	public function actionListMedias() {
		
		//////////////////////////////////////////////
		// 1、管理员可以常看所有的媒体文件
		// 2、非管理员只能查看自己的媒体文件
		//////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			//用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$sql = "SELECT * FROM MediaFiles";
		
		$hasParent = false;
		
		if (isset ( $DataParam ['Parent'] )) { //根据父节点筛选
			$parent = $DataParam ['Parent'];
			
			if (is_numeric ( $parent )) {
				
				if ($parent == 0) {
					$sql = $sql . " WHERE ISNULL(Parent)";
				} else {
					$sql = $sql . " WHERE Parent='" . $parent . "'";
				}
				$hasParent = true;
			}
		}
		
		if (! $hasParent) { //获取一级目录
			if (is_null ( $UserID ) || $UserID == 0) { //超级管理员登录
				$sql = $sql . " WHERE (ISNULL(Parent) OR LENGTH(Parent) <= 0)";
			} else { //普通给用户登录，只能够获取到自己的
				$sql = $sql . " WHERE Parent IN(SELECT MediaID FROM MediaFiles WHERE Parent IN(SELECT MediaID FROM MediaFiles WHERE ISNULL(Owner) AND Sysfolder = 2) 
					AND Owner = " . $UserID . " AND Sysfolder = 1)";
			}
		}
		
		//		if (! is_null ( $UserID ) && $UserID > 0) { //非管理员用户登录
		//			if (! $hasParent) {
		//				$sql .= ' WHERE (Parent IN (SELECT MIN(MediaID) FROM MediaFiles WHERE TotalTime = 0 AND Owner="' . $UserID . '"))';
		//			}
		//		} else {
		//			if ($hasParent == false) {
		//				$sql .= " WHERE Parent is null";
		//			}
		//		}
		

		if (isset ( $DataParam ['IsVideo'] ) && is_numeric ( $DataParam ['IsVideo'] )) { //根据音视频类型筛选, 1:视频，0：音频
			if ($DataParam ['IsVideo'] == 1) { //视频
				$sql .= ' AND (FileFmt IN(-1,2,3,4) OR (FileSize=0 AND TotalTime=0 AND FileFmt=0))';
			} else if ($DataParam ['IsVideo'] == 0) { //音频
				$sql .= ' AND (FileFmt IN(0,1) OR (FileSize=0 AND TotalTime=0 AND FileFmt=0))';
			}
		}
		$ParamArr = array ();
		if (isset ( $DataParam ['SearchKey'] )) { //按照关键字搜索
			$ParamArr [':SearchKey'] = $DataParam ['SearchKey'];
			$sql .= ' AND FileName LIKE CONCAT("%", :SearchKey, "%")';
		}
		$sql .= '  ORDER BY TotalTime ASC';
		
		if (isset ( $DataParam ['Start'] ) && isset ( $DataParam ['Size'] )) {
			$start = $DataParam ['Start'];
			$size = $DataParam ['Size'];
			
			if (is_numeric ( $start ) && is_numeric ( $size )) {
				$sql .= '  LIMIT ' . $start . ', ' . $size;
			}
		}
		
		$result = DBMethodUtils::listData ( $sql, $ParamArr );
		
		$Out = array ();
		
		if (! empty ( $result )) {
			foreach ( $result as $value ) {
				if ($value ['TotalTime'] == 0) {
					$value ['FileType'] = self::MediaImageIndexGroup;
				} else {
					switch ($value ['FileFmt']) {
						case 0 :
							$value ['FileType'] = self::MediaImageIndexCelt;
							break;
						case - 1 :
							$value ['FileType'] = self::MediaImageIndexUrl;
							break;
						default :
							if ($value ['VedioCodec'] == - 1) {
								$value ['FileType'] = self::MediaImageIndexAudio;
							} else {
								$value ['FileType'] = self::MediaImageIndexVedio;
							}
							break;
					}
				}
				
				$Out [] = $value;
			}
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $Out );
	}
	
	/**
	 * 上传媒体文件
	 */
	public function actionUpload() {
		
		/***************************
		 * 
		 * 
		 * ***************************/
		$DataParam = $this->LoadDataParam ();
		
		if (empty ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		
		//用户Id
		$UserId = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserId ) && $UserId < 0) {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '上传失败', null );
			return;
		}
		$Parent = $this->GetDataParam ( $DataParam, 'Parent', null, true ); //父节点Id
		$File = CUploadedFile::getInstanceByName ( "Filename" );
		
		if (empty ( $File )) { //文件上传失败
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '上传失败', null );
			return;
		}
		//		$TempDir = 'temp/';
		//		$DistDir = 'media/';
		

		$TempDir = '/home/upload/temp/';
		$DistDir = '/home/upload/media/';
		
		if (! file_exists ( $TempDir )) {
			mkdir ( $TempDir );
			chmod ( $TempDir, 777 );
		}
		if (! file_exists ( $DistDir )) {
			mkdir ( $DistDir );
			chmod ( $DistDir, 777 );
		}
		$filename = $TempDir . time ();
		
		if (! $File->saveAs ( $filename )) { //保存文件失败
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '上传失败', null );
			return;
		}
		//		
		//		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '上传成功', null );
		//		return;
		//		//TODO
		//文件上传成功，需要获取文件信息
		$Cmd = 'idprobe -v quiet -print_format json -show_format -show_streams ' . $filename;
		$OutArr = array ();
		exec ( $Cmd, $OutArr );
		$TempData = CJSON::decode ( implode ( "", $OutArr ) );
		
		$AudioValidArr = array ("mp3", "mp2", "aac" );
		$VideoValidArr = array ("h264", "mpeg4", "mpeg2video" );
		$FileFmtArr = array ("celt" => "0", "mp3" => "1", "mpegts" => "2", "mov,mp4,m4a,3gp,3g2,mj2" => "3", "avi" => "4" );
		
		if (empty ( $TempData ['streams'] [0] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '上传失败', null );
			return;
		}
		$format = $TempData ['format'];
		$streams = null;
		//$TempData ['streams'] [0];
		$streams1 = null;
		//empty ( $TempData ['streams'] [1] ) ? null : $TempData ['streams'] [1];
		

		if (! empty ( $TempData ['streams'] )) {
			foreach ( $TempData ['streams'] as $item ) {
				if (empty ( $item ['codec_type'] )) {
					continue;
				}
				$codec_type = $item ['codec_type'];
				
				if ("video" == strtolower ( $codec_type )) { //视频
					$streams = $item;
				} elseif ("audio" == strtolower ( $codec_type )) { //音频
					$streams1 = $item;
				}
			}
		}
		$codec_type = empty ( $streams ['codec_type'] ) ? "" : $streams ['codec_type'];
		$codec_name = empty ( $streams ['codec_name'] ) ? "" : $streams ['codec_name'];
		$codec_type1 = empty ( $streams1 ['codec_type'] ) ? "" : $streams1 ['codec_type'];
		$codec_name2 = empty ( $streams1 ['codec_name'] ) ? "" : $streams1 ['codec_name'];
		$VedioCodec = - 1; //int(11)	0: h264；1: mpeg4，2：MPEG2，-1没有视频
		$AudioCodec = - 1; //int(11)	0: celt；1: mp3；2：mp2，3: aac,-1没有音频
		$TempFileFmt = AMediaUtil::GetStreamValue ( $format, 'format_name' );
		$FileFmt = isset ( $FileFmtArr [$TempFileFmt] ) ? $FileFmtArr [$TempFileFmt] : 0; //int(11)	0: celt；1: mp3；2: ts；3: mp4, mov；4: avi 注：-1直播，0，1音频，2,3,4视频
		

		if ("video" == strtolower ( $codec_type ) && in_array ( $codec_name, $VideoValidArr )) { //视频
			if ("h264" == strtolower ( $codec_name )) {
				$VedioCodec = 0;
			} else if ("mpeg4" == strtolower ( $codec_name )) {
				$VedioCodec = 1;
			} else if ("mpeg2video" == strtolower ( $codec_name )) {
				$VedioCodec = 2;
			}
			
			if ("mp3" == strtolower ( $codec_name2 )) {
				$AudioCodec = 1;
			} else if ("mp2" == strtolower ( $codec_name2 )) {
				$AudioCodec = 2;
			} else if ("aac" == strtolower ( $codec_name2 )) {
				$AudioCodec = 3;
			}
		} elseif ("audio" == strtolower ( $codec_type1 )) { //音频
			if (! in_array ( $codec_name2, $AudioValidArr )) { //格式不争取，上传失败
				echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '上传失败', null );
				return;
			}
			if ("mp3" == strtolower ( $codec_name2 )) {
				$AudioCodec = 1;
			} else if ("mp2" == strtolower ( $codec_name2 )) {
				$AudioCodec = 2;
			} else if ("aac" == strtolower ( $codec_name2 )) {
				$AudioCodec = 3;
			}
			
			if (strtolower ( $codec_name2 ) == "mp3") { //mp3文件需要转码
				$TempOutput = array ();
				$newfilename = $TempDir . time () . '-temp';
				$cmd = 'audio_convert ' . $filename . ' ' . $newfilename;
				exec ( $cmd, $TempOutput );
				unlink ( $filename );
				$filename = $newfilename;
				
				//需要重新获取数据
				$Cmd = 'idprobe -v quiet -print_format json -show_format -show_streams ' . $filename;
				$OutArr = array ();
				exec ( $Cmd, $OutArr );
				$TempData = CJSON::decode ( implode ( "", $OutArr ) );
				
				$AudioCodec = 0;
				$FileFmt = 0;
			}
		}
		$streams = empty ( $streams ) ? $streams1 : $streams;
		
		$TotalTime = AMediaUtil::GetStreamValue ( $streams, 'duration' ); //	int(11)	默认是0
		$BitRate = AMediaUtil::GetStreamValue ( $format, 'bit_rate' ); //int(11)	传输码率
		$BitRate = floor ( $BitRate / 1000 );
		$Height = AMediaUtil::GetStreamValue ( $streams, 'height' ); //int(11)	视频高度
		$Width = AMediaUtil::GetStreamValue ( $streams, 'width' ); //int(11)	视频宽度
		$FrameRate = AMediaUtil::GetStreamValue ( $streams, 'avg_frame_rate' ); //int(11)	视频帧率
		$FrameRateArr = explode ( "/", $FrameRate );
		$FrameRate = (count ( $FrameRateArr ) >= 2 && $FrameRateArr [1] > 0) ? floor ( floor ( $FrameRateArr [0] ) / floor ( $FrameRateArr [1] ) ) : 0;
		$Channels = AMediaUtil::GetStreamValue ( $streams, 'channels' ); //	int(11)	声道
		$Channels = empty ( $Channels ) ? AMediaUtil::GetStreamValue ( $streams1, 'channels' ) : $Channels;
		$SampleRate = AMediaUtil::GetStreamValue ( $streams, 'sample_rate' ); //int(11)	采样率
		$SampleRate = empty ( $SampleRate ) ? AMediaUtil::GetStreamValue ( $streams1, 'sample_rate' ) : $SampleRate;
		
		$arr = explode ( ".", $File->name );
		$SaveFileName = $File->name;
		
		if ($arr != null && count ( $arr ) > 1) {
			$tempArr = array_slice ( $arr, 0, count ( $arr ) - 1 );
			$SaveFileName = implode ( ".", $tempArr );
		}
		//处理上传文件的位置
		$Owner = $UserId;
		
		$model = new MediaFiles ();
		$model->FileName = $SaveFileName;
		$model->FileSize = filesize ( $filename );
		$model->TotalTime = floor ( $TotalTime );
		$model->FileFmt = floor ( $FileFmt );
		$model->BitRate = floor ( $BitRate );
		$model->VedioCodec = floor ( $VedioCodec );
		$model->Height = floor ( $Height );
		$model->Width = floor ( $Width );
		$model->FrameRate = floor ( $FrameRate );
		$model->AudioCodec = floor ( $AudioCodec );
		$model->Channels = floor ( $Channels );
		$model->SampleRate = floor ( $SampleRate );
		$model->Parent = AMediaUtil::getParent ( $UserId, $Parent );
		$model->Gain = 0;
		$model->CreateTime = date ( 'Y-m-d H:i:s' );
		$model->FilePath = "";
		$model->Owner = null;
		$model->Sysfolder = null;
		
		if ($model->FileSize > 0 && $model->TotalTime > 0 && $model->BitRate > 0 && $model->save ()) {
			$distPath = $DistDir . $model->MediaID;
			//			$distPath = 'temp/' . $model->MediaID;
			rename ( $filename, $distPath );
			$model->FilePath = $distPath;
			$model->save ();
			
			echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '上传成功', null );
		} else {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '上传失败', null );
		}
	}
	
	/**
	 * 添加节目源
	 */
	public function actionUploadProgram() {
		
		$DataParam = $this->LoadDataParam ();
		
		if (empty ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		//用户Id
		$UserId = $this->GetPostOwnerID ();
		$Parent = $this->GetDataParam ( $DataParam, 'Parent', null ); //父节点ID
		$Name = $this->GetDataParam ( $DataParam, 'Name', null ); //媒体名字
		$Addr = $this->GetDataParam ( $DataParam, 'Addr', null ); //网址
		

		if (empty ( $Name ) || empty ( $Addr )) {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '上传失败', null );
			return;
		}
		
		$model = new MediaFiles ();
		$model->FileName = $Name;
		$model->FileSize = 0;
		$model->TotalTime = 10;
		$model->FileFmt = - 1;
		$model->BitRate = 0;
		$model->VedioCodec = - 1;
		$model->Height = 0;
		$model->Width = 0;
		$model->FrameRate = 0;
		$model->AudioCodec = - 1;
		$model->Channels = 0;
		$model->SampleRate = 0;
		$model->Parent = AMediaUtil::getParent ( $UserId, $Parent );
		$model->Gain = 0;
		$model->CreateTime = date ( 'Y-m-d H:i:s' );
		$model->FilePath = $Addr;
		$model->Owner = null;
		$model->Sysfolder = null;
		
		if ($model->save ()) {
			echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '上传成功', null );
		} else {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '上传失败', null );
		}
	}
	
	/**
	 * 删除媒体文件
	 */
	public function actionDelete() {
		
		/************************************************
		 * 1、超级管理员可以删除所有
		 * 2、普通管理员只能删除自己的
		 ************************************************/
		$DataParam = $this->LoadDataParam ();
		
		if (empty ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		//获取用户
		$UserId = $this->GetPostOwnerID ();
		//需要删除的文件id,格式：1,2,3,4
		$MediaIds = $this->GetDataParam ( $DataParam, 'MediaIds', '' );
		
		//处理问价id
		$Arr = explode ( ',', $MediaIds );
		$TempArr = array ();
		
		foreach ( $Arr as $value ) {
			if (! is_numeric ( $value )) {
				continue;
			}
			$TempArr [] = $value;
		}
		
		if (empty ( $TempArr )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		
		//需要删除当前文件及其子文件
		foreach ( $TempArr as $FileId ) {
			$sql = "set max_sp_recursion_depth=10;";
			DBMethodUtils::RunSql ( $sql );
			DBMethodUtils::RunSql ( "call sp_del_media_file( " . (is_null ( $UserId ) ? 0 : $UserId) . ", " . $FileId . ")" );
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '删除完成', null );
	}
	
	/**
	 * 新建文件夹
	 */
	public function actionAddDir() {
		
		$DataParam = $this->LoadDataParam ();
		
		if (empty ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		//获取用户
		$UserId = $this->GetPostOwnerID ();
		//文件夹名称
		$Name = $this->GetDataParam ( $DataParam, 'Name', '' );
		//父节点
		$Parent = $this->GetDataParam ( $DataParam, 'Parent', 0, true );
		
		if (! is_null ( $UserId )) { //不是超级管理员（文件夹只能新建在自己的目录下）
			$NeedNewParent = false; //不需要新的父节点
			

			if (! empty ( $Parent )) { //不是顶级
				$ParentFile = MediaFiles::model ()->findByPk ( $Parent );
				
				if (empty ( $ParentFile ) || $ParentFile->Owner != $UserId) { //需要新的父节点
					$NeedNewParent = true;
				}
			} else { //顶级目录
				$NeedNewParent = true;
			}
			if ($NeedNewParent) {
				//获取用户文件夹
				$UserFolder = AMediaUtil::LoadUserFolder ();
				
				if (empty ( $UserFolder )) { //这里需要新建一条记录
					echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '新建文件夹失败', null );
					return;
				}
				//
				$UserOneFolder = AMediaUtil::LoadUserOneFolder ( $UserId, $UserFolder->MediaID );
				
				if (empty ( $UserOneFolder )) {
					echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '新建文件夹失败', null );
					return;
				}
				$Parent = $UserOneFolder->MediaID;
			}
		}
		
		$Media = new MediaFiles ();
		$Media->FileName = $Name;
		$Media->TotalTime = 0;
		$Media->Parent = empty ( $Parent ) ? null : $Parent;
		$Media->Owner = empty ( $UserId ) ? null : $UserId;
		$Media->FileSize = 0;
		$Media->TotalTime = 0;
		$Media->FileFmt = 0;
		$Media->BitRate = 0;
		$Media->VedioCodec = 0;
		$Media->Height = 0;
		$Media->Width = 0;
		$Media->FrameRate = 0;
		$Media->AudioCodec = 0;
		$Media->Channels = 0;
		$Media->SampleRate = 0;
		$Media->Gain = 0;
		$Media->Owner = $UserId;
		try {
			if ($Media->save ()) {
				echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '新建文件夹成功', $Media );
				return;
			}
		} catch ( Exception $e ) {
		
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '新建文件夹失败', null );
		return;
	}
	
	/**
	 * 文件夹/文件重命名
	 */
	public function actionRename() {
		
		/**********************************************
		 * 只能对非系统文件命名
		 **********************************************/
		
		$DataParam = $this->LoadDataParam ();
		
		if (empty ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		//获取用户
		$UserId = $this->GetPostOwnerID ();
		//Id
		$MediaID = $this->GetDataParam ( $DataParam, 'MediaID', 0, true );
		//新的名称
		$Name = $this->GetDataParam ( $DataParam, 'Name', '' );
		//音量增益（仅文件有效）
		$Gain = $this->GetDataParam ( $DataParam, 'Gain', 0, true );
		//网址
		$Addr = $this->GetDataParam ( $DataParam, 'Addr', '' );
		
		if ($Gain <= - 10) {
			$Gain = 10;
		}
		
		if ($Gain >= 10) {
			$Gain = 10;
		}
		$Media = MediaFiles::model ()->findByPk ( $MediaID );
		
		if (empty ( $Media )) {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '文件不存在修改失败', null );
			return;
		}
		$Media->FileName = $Name;
		$Media->Gain = $Gain;
		
		if ($Media->FileFmt == - 1) { //直播需要修改路径
			if (! empty ( $Addr )) {
				$Media->FilePath = $Addr;
			}
		}
		
		if ($Media->save ()) {
			echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '修改成功', $Media );
			return;
		}
		echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '修改失败', null );
		return;
	}
	
}