<?php
class BWPlayerManager {
	
	const USER_INFO = "webApp:webApp";
	
	/**
	 * BW801本地曲目信息获取
	 * 返回数据结构：[{"DirID":"01","DirName":"升旗和运动会系列","MP3file":[{"FileId":"02","FileName":"国歌"}]}]
	 */
	public static function listPlayerMusic($Ip) {
		
		$url = "http://" . BWPlayerManager::USER_INFO . "@" . $Ip . "/cgi-bin/getmusic.cgi";
		$res = BWPlayerManager::PostData ( $url );
		
		if (empty ( $res )) {
			return null;
		}
		
		return CJSON::decode ( $res );
	}
	
	/**
	 * 移动APP获取BW801当前状态信息
	 * 返回数据结构：[{"CurDirID":"01","CurDirName":"升旗和运动会系列","CurFileId":"02","FileName":"国歌","brdState":"0","BrdGrpMember":"01","inputLine1":"0","inputLine2":"0","inputMic":"0","Mp3PlayState":"0","playTime":"XXXX"}]
	 */
	public static function loadPlayerCurrentStatus($Ip) {
		
		$url = "http://" . BWPlayerManager::USER_INFO . "@" . $Ip . "/cgi-bin/getplayerst.cgi";
		$res = BWPlayerManager::PostData ( $url );

		if (empty ( $res )) {
			return null;
		}
		$Datas = CJSON::decode ( $res );
		
		if (empty ( $Datas )) {
			return null;
		}
		
		if (count ( $Datas ) > 0) {
			return $Datas [0];
		}
		
		return null;
	}
	
	/**
	 * 广播分区设置
	 * @param $Ip
	 * @param $brdGrpCtrl 当前选定的广播分区，该值为一个16bit的值，低10位的每一个bit表示一个分区是否已经选上，高6个bit置0，低10个比特含义，bit为0表示勾选分区，比特为1表示分区已选
	 */
	public static function Playerbrdgrpset($Ip, $brdGrpCtrl) {
		
		$url = "http://" . BWPlayerManager::USER_INFO . "@" . $Ip . "/cgi-bin/playerbrdgrpset.cgi";
		$Param = "brdGrpCtrl=" . $brdGrpCtrl;
		$res = BWPlayerManager::PostData ( $url, $Param );
		
		return $res;
	}
	
	/**
	 * 设备控制
	 * @param  $Ip 设备IP地址
	 * @param  $brdCtrl 是否打开广播，0：关闭，1：打开（不传为不修改）
	 * @param  $line1Input 是否打开线路1输入，0：关闭，1：打开（不传为不修改）
	 * @param  $line2Input 是否打开线路2输入，0：关闭，1：打开（不传为不修改）
	 * @param  $micInput 是否打开麦克风输入，0：关闭，1：打开（不传为不修改）
	 * @param  $mp3PlayCtrl 是否播放MP3文件，0：停止，1：播放（不传为不修改）, 2：暂停 （不传为不修改）
	 * @param  $mp3FileChange 0:当前文件，1：上一首，2：下一首，3：指定MP3文件（不传为不修改）
	 * @param  $dirId 指定MP3文件所在的目录号，当Mp3FileChange 为3时，这1参数为必传参数
	 * @param  $fileId 指定MP3文件所在目录的文件ID号，当Mp3FileChange 为3时，这1参数为必传参数
	 * failed：修改失败，success：成功
	 */
	public static function PlayerCtrlSet($Ip, $brdCtrl, $line1Input, $line2Input, $micInput, $mp3PlayCtrl, $mp3FileChange, $dirId, $fileId) {
		
		$ParamArr = array ();
		
		//是否打开广播，0：关闭，1：打开（不传为不修改）
		if (in_array ( $brdCtrl, array ("0", "1" ) )) {
			$ParamArr [] = "brdCtrl=" . $brdCtrl;
		}
		//是否打开线路1输入，0：关闭，1：打开（不传为不修改）
		if (in_array ( $line1Input, array ("0", "1" ) )) {
			$ParamArr [] = "line1Input=" . $line1Input;
		}
		//是否打开线路2输入，0：关闭，1：打开（不传为不修改）
		if (in_array ( $line2Input, array ("0", "1" ) )) {
			$ParamArr [] = "line2Input=" . $line2Input;
		}
		//是否打开麦克风输入，0：关闭，1：打开（不传为不修改）
		if (in_array ( $micInput, array ("0", "1" ) )) {
			$ParamArr [] = "micInput=" . $micInput;
		}
		//是否播放MP3文件，0：停止，1：播放（不传为不修改）, 2：暂停 （不传为不修改）
		if (in_array ( $mp3PlayCtrl, array ("0", "1", "2" ) )) {
			$ParamArr [] = "mp3PlayCtrl=" . $mp3PlayCtrl;
		}
		//0:当前文件，1：上一首，2：下一首，3：指定MP3文件（不传为不修改）
		if (in_array ( $mp3FileChange, array ("0", "1", "2", "3" ) )) {
			
			if ($mp3FileChange == "3") {
				if (! empty ( $dirId ) && ! empty ( $fileId )) { //指定MP3文件所在的目录号，当Mp3FileChange 为3时，这1参数为必传参数；指定MP3文件所在目录的文件ID号，当Mp3FileChange 为3时，这1参数为必传参数
					//TODO 这里需要考虑是否需要校验目录和文件的有效性
					$ParamArr [] = "mp3FileChange=" . $mp3FileChange;
					$ParamArr [] = "dirId=" . $dirId;
					$ParamArr [] = "fileId=" . $fileId;
				}
			} else {
				$ParamArr [] = "mp3FileChange=" . $mp3FileChange;
			}
		}
		$url = "http://" . BWPlayerManager::USER_INFO . "@" . $Ip . "/cgi-bin/playerctrlset.cgi";
		$res = BWPlayerManager::PostData ( $url, implode ( "&", $ParamArr ) );
		
		return $res;
	}
	
	////////////////////////////////////////////////////////////////////////////
	/**
	 * POST数据
	 * @param $url 地址
	 * @param $postData 参数
	 * @param $timeout 超时时间，单位：秒
	 */
	public static function PostData($url, $postData = '', $timeout = 15) { //curl
		

		$ch = curl_init ();
		curl_setopt ( $ch, CURLOPT_URL, $url );
		
		if (! empty ( $postData )) {
			curl_setopt ( $ch, CURLOPT_POST, true );
			curl_setopt ( $ch, CURLOPT_POSTFIELDS, $postData );
		}
		curl_setopt ( $ch, CURLOPT_RETURNTRANSFER, 1 );
		curl_setopt ( $ch, CURLOPT_CONNECTTIMEOUT, $timeout );
		curl_setopt ( $ch, CURLOPT_HEADER, false );
		$file_contents = curl_exec ( $ch );
		curl_close ( $ch );
		
//		echo $url . "====>" . $file_contents . "==========>";
		
		return $file_contents;
	}
}