<?php
class BaseController extends Controller {

	/**
	 * 获取并解析DataParam参数值
	 */
	protected function LoadDataParam() {

		if (! isset ( $_POST ['DataParam'] )) {
			return null;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );

		if (empty ( $DataParam )) {
			return null;
		}

		return $DataParam;
	}

	/**
	 * 获取DataParam中key对应值值
	 * @param  $DataParam
	 * @param  $Key
	 * @param  $Default
	 * @param  $IsNumber
	 */
	protected function GetDataParam($DataParam, $Key, $Default, $IsNumber = false) {

		if (! isset ( $DataParam [$Key] )) {
			return $Default;
		}
		if ($IsNumber && ! is_numeric ( $DataParam [$Key] )) {
			return $Default;
		}

		return $DataParam [$Key];
	}

	/**
	 * 获取上传的角色ID信息，如果为负数表示没有上传角色id
	 */
	protected function GetPostOwnerID() {

		$UserID = - 1;

		if (isset ( $_POST ['UserID'] )) {
			$UserID = $_POST ['UserID'];
		}

		if ($UserID == 0) {
			return null;
		}

		return $UserID;
	}

	/**
	 *
	 * Enter description here ...
	 * @param unknown_type $OutData
	 */
	public function PackResponseDataAll($OutData) {

		return $this->PackResponseData ( $OutData ['ErrCode'], $OutData ['ErrMsg'], $OutData ['Data'] );
	}

	/**
	 *
	 * @param unknown_type $cat
	 * @param unknown_type $key
	 */
	public function getStr($cat, $key) {

		return LanguageUtil::getStr ( $cat, $key );
	}

	/**
	 * 组装响应的数据
	 * @param $Code 错误代码
	 * @param $Description 错误描述
	 * @param $Data 响应的数据
	 */
	public function PackResponseData($Code, $Description, $Data) {

		$key = 'err_msg_' . $Code;
		$tempDescription = $this->getStr ( 'appcommon', $key );

		if ($tempDescription != $key) {
			$Description = $tempDescription;
		}
		$Response = array ('ErrCode' => $Code, 'ErrMsg' => $Description, 'Data' => $Data );

		if (! empty ( $_POST ['IsGz'] ) && $_POST ['IsGz'] == 1) {
			return base64_encode ( gzcompress ( CJSON::encode ( $Response ), 9 ) );
		}

		return CJSON::encode ( $Response );
	}

	/**
	 * 组装响应的数据
	 * @param $Code 错误代码
	 * @param $Description 错误描述
	 * @param $Data 响应的数据
	 */
	public function PackResponseDataParamErr() {

		return $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
	}

	/**
	 * 判断用户是否有多媒体平台控制权限(中控设备的管理权限)
	 * @param $UserId 用户ID
	 * @return true : 有权限，false：没有权限
	 */
	public function JudgeDevCtrPrivaliege($UserId) {

		if (is_null ( $UserId )) {
			$UserId = 0;
		}
		if ($UserId == 0) {
			return true;
		}
		$User = Users::model ()->findByPk ( $UserId );

		if (is_null ( $User ) || ! isset ( $User ['privilege'] )) {
			return false;
		}

		return PermissionManager::JudgeDevCtrPrivaliege ( $User ['privilege'] );
	}

	/**
	 * 判断是否具有IC卡管理权限
	 * @param $UserId
	 * @param $privilege
	 */
	public function JudgeICMgrPrivaliege($UserId) {

		if (is_null ( $UserId )) {
			$UserId = 0;
		}
		if ($UserId == 0) {
			return true;
		}
		$User = Users::model ()->findByPk ( $UserId );

		if (is_null ( $User ) || ! isset ( $User ['privilege'] )) {
			return false;
		}

		return PermissionManager::JudgeICMgrPrivaliege ( $User ['privilege'] );
	}

	/**
	 * 浏览权限
	 * @param $UserId
	 * @param $privilege
	 */
	public function JudgeScanPrivaliege($UserId) {

		if (is_null ( $UserId )) {
			$UserId = 0;
		}
		if ($UserId == 0) {
			return true;
		}
		$User = Users::model ()->findByPk ( $UserId );

		if (is_null ( $User ) || ! isset ( $User ['privilege'] )) {
			return false;
		}

		return PermissionManager::JudgeScanPrivaliege ( $User ['privilege'] );
	}

	/**
	 * 判断用户是否有广播权限权限
	 * @param $UserId 用户ID
	 */
	public function JudgeBroadcastPrivaliege($UserId) {

		if (is_null ( $UserId )) {
			$UserId = 0;
		}
		if ($UserId == 0) {
			return true;
		}
		$User = Users::model ()->findByPk ( $UserId );

		if (is_null ( $User ) || ! isset ( $User ['privilege'] )) {
			return false;
		}

		return PermissionManager::JudgeBroadcastPrivaliege ( $User ['privilege'] );
	}

    /**
     * 判断用户是否有IP呼叫权限
     * @param $UserId 用户ID
     */
    public function JudgeIpcallPrivaliege($UserId) {

        if (is_null ( $UserId )) {
            $UserId = 0;
        }
        if ($UserId == 0) {
            return true;
        }
        $User = Users::model ()->findByPk ( $UserId );

        if (is_null ( $User ) || ! isset ( $User ['privilege'] )) {
            return false;
        }

        return PermissionManager::JudgeIpcallPrivaliege ( $User ['privilege'] );
    }

	/**
	 * 判断用户是否有物联设备权限权限
	 * @param $UserId 用户ID
	 */
	public function JudgeRfDevCtrPrivaliege($UserId) {

		if (is_null ( $UserId )) {
			$UserId = 0;
		}
		if ($UserId == 0) {
			return true;
		}
		$User = Users::model ()->findByPk ( $UserId );

		if (is_null ( $User ) || ! isset ( $User ['privilege'] )) {
			return false;
		}

		return PermissionManager::JudgeRfDevCtrPrivaliege ( $User ['privilege'] );
	}

	/***************************************************************************************/
	/**
	 * 加载权限
	 */
	public function LoadPermission($UserId) {

		//复制、删除权限
		$Permission = array ();
		//$Permission ['DevDelete'] = $UserId == 0 ? 1 : 0; //设备删除权限
		$Permission ['IsAdmin'] = $UserId == 0 ? 1 : 0; //设备复制权限

		if ($Permission ['IsAdmin'] == 1) {
			$Permission ['DevCtrPermission'] = 1; //中控设备的管理权限
			$Permission ['RfDevCtrPermission'] = 1; //物联设备管理权限
            $Permission ['BroadcastPermission'] = 1; //音视频广播权限
            $Permission ['IpcallPermission'] = 1; //音视频广播权限
			$Permission ['ICPermission'] = 1; //IC卡管理权限
			$Permission ['ScanPermission'] = 1; //bit5: 浏览权限
		} else {
			$Permission ['DevCtrPermission'] = $this->JudgeDevCtrPrivaliege ( $UserId ) ? 1 : 0; //中控设备的管理权限
			$Permission ['RfDevCtrPermission'] = $this->JudgeRfDevCtrPrivaliege ( $UserId ) ? 1 : 0; //物联设备管理权限
            $Permission ['BroadcastPermission'] = $this->JudgeBroadcastPrivaliege ( $UserId ) ? 1 : 0; //音视频广播权限
            $Permission ['IpcallPermission'] = $this->JudgeIpCallPrivaliege ( $UserId ) ? 1 : 0; //音视频广播权限
			$Permission ['ICPermission'] = $this->JudgeICMgrPrivaliege ( $UserId ) ? 1 : 0; //IC卡管理权限
			$Permission ['ScanPermission'] = $this->JudgeScanPrivaliege ( $UserId ) ? 1 : 0; //bit5: 浏览权限
		}

		return $Permission;
	}
}