<?php

/**
 * This is the model class for table "DevCtrlSchedule".
 *
 * The followings are the available columns in table 'DevCtrlSchedule':
 * @property string $ScheduleID
 * @property string $DevID
 * @property string $ActionTime
 * @property integer $Action
 * @property integer $WeekDay
 * @property integer $State
 * @property string $ExtArgs
 * @property integer $Disable
 *
 * The followings are the available model relations:
 * @property Devicelist $dev
 */
class DevCtrlSchedule extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'DevCtrlSchedule';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('DevID, ActionTime, WeekDay', 'required'),
			array('Action, WeekDay, State, Disable', 'numerical', 'integerOnly'=>true),
			array('DevID', 'length', 'max'=>50),
			array('ExtArgs', 'length', 'max'=>256),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('ScheduleID, DevID, ActionTime, Action, WeekDay, State, ExtArgs, Disable', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'dev' => array(self::BELONGS_TO, 'Devicelist', 'DevID'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'ScheduleID' => 'Schedule',
			'DevID' => 'Dev',
			'ActionTime' => 'Action Time',
			'Action' => 'Action',
			'WeekDay' => 'Week Day',
			'State' => 'State',
			'ExtArgs' => 'Ext Args',
			'Disable' => 'Disable',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('ScheduleID',$this->ScheduleID,true);
		$criteria->compare('DevID',$this->DevID,true);
		$criteria->compare('ActionTime',$this->ActionTime,true);
		$criteria->compare('Action',$this->Action);
		$criteria->compare('WeekDay',$this->WeekDay);
		$criteria->compare('State',$this->State);
		$criteria->compare('ExtArgs',$this->ExtArgs,true);
		$criteria->compare('Disable',$this->Disable);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return DevCtrlSchedule the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
