<?php

/**
 * This is the model class for table "MediaFiles".
 *
 * The followings are the available columns in table 'MediaFiles':
 * @property integer $MediaID
 * @property string $FileName
 * @property string $FileSize
 * @property integer $TotalTime
 * @property integer $FileFmt
 * @property integer $BitRate
 * @property integer $VedioCodec
 * @property integer $Height
 * @property integer $Width
 * @property integer $FrameRate
 * @property integer $AudioCodec
 * @property integer $Channels
 * @property integer $SampleRate
 * @property integer $Parent
 * @property integer $Gain
 * @property string $CreateTime
 * @property string $FilePath
 * @property integer $Owner
 * @property integer $Sysfolder
 *
 * The followings are the available model relations:
 * @property Mediafiles $parent
 * @property Users $owner
 */
class MediaFiles extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'MediaFiles';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('TotalTime, FileFmt, BitRate, VedioCodec, Height, Width, FrameRate, AudioCodec, Channels, SampleRate, Parent, Gain, Owner, Sysfolder', 'numerical', 'integerOnly'=>true),
			array('FileName', 'length', 'max'=>64),
			array('FileSize', 'length', 'max'=>20),
			array('FilePath', 'length', 'max'=>256),
			array('CreateTime', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('MediaID, FileName, FileSize, TotalTime, FileFmt, BitRate, VedioCodec, Height, Width, FrameRate, AudioCodec, Channels, SampleRate, Parent, Gain, CreateTime, FilePath, Owner, Sysfolder', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'parent' => array(self::BELONGS_TO, 'Mediafiles', 'Parent'),
			'owner' => array(self::BELONGS_TO, 'Users', 'Owner'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'MediaID' => 'Media',
			'FileName' => 'File Name',
			'FileSize' => 'File Size',
			'TotalTime' => 'Total Time',
			'FileFmt' => 'File Fmt',
			'BitRate' => 'Bit Rate',
			'VedioCodec' => 'Vedio Codec',
			'Height' => 'Height',
			'Width' => 'Width',
			'FrameRate' => 'Frame Rate',
			'AudioCodec' => 'Audio Codec',
			'Channels' => 'Channels',
			'SampleRate' => 'Sample Rate',
			'Parent' => 'Parent',
			'Gain' => 'Gain',
			'CreateTime' => 'Create Time',
			'FilePath' => 'File Path',
			'Owner' => 'Owner',
			'Sysfolder' => 'Sysfolder',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('MediaID',$this->MediaID);
		$criteria->compare('FileName',$this->FileName,true);
		$criteria->compare('FileSize',$this->FileSize,true);
		$criteria->compare('TotalTime',$this->TotalTime);
		$criteria->compare('FileFmt',$this->FileFmt);
		$criteria->compare('BitRate',$this->BitRate);
		$criteria->compare('VedioCodec',$this->VedioCodec);
		$criteria->compare('Height',$this->Height);
		$criteria->compare('Width',$this->Width);
		$criteria->compare('FrameRate',$this->FrameRate);
		$criteria->compare('AudioCodec',$this->AudioCodec);
		$criteria->compare('Channels',$this->Channels);
		$criteria->compare('SampleRate',$this->SampleRate);
		$criteria->compare('Parent',$this->Parent);
		$criteria->compare('Gain',$this->Gain);
		$criteria->compare('CreateTime',$this->CreateTime,true);
		$criteria->compare('FilePath',$this->FilePath,true);
		$criteria->compare('Owner',$this->Owner);
		$criteria->compare('Sysfolder',$this->Sysfolder);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return MediaFiles the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
