<?php

/**
 * This is the model class for table "PlaySessionTime".
 *
 * The followings are the available columns in table 'PlaySessionTime':
 * @property integer $ScheduleID
 * @property integer $SessionID
 * @property integer $WeekDay
 * @property string $PlayTime
 * @property integer $TempFlag
 *
 * The followings are the available model relations:
 * @property Playsessions $session
 */
class PlaySessionTime extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'PlaySessionTime';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('SessionID, WeekDay, PlayTime', 'required'),
			array('SessionID, WeekDay, TempFlag', 'numerical', 'integerOnly'=>true),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('ScheduleID, SessionID, WeekDay, PlayTime, TempFlag', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'session' => array(self::BELONGS_TO, 'Playsessions', 'SessionID'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'ScheduleID' => 'Schedule',
			'SessionID' => 'Session',
			'WeekDay' => 'Week Day',
			'PlayTime' => 'Play Time',
			'TempFlag' => 'Temp Flag',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('ScheduleID',$this->ScheduleID);
		$criteria->compare('SessionID',$this->SessionID);
		$criteria->compare('WeekDay',$this->WeekDay);
		$criteria->compare('PlayTime',$this->PlayTime,true);
		$criteria->compare('TempFlag',$this->TempFlag);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return PlaySessionTime the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
