<?php

/**
 * This is the model class for table "PlayerKeys".
 *
 * The followings are the available columns in table 'PlayerKeys':
 * @property integer $PlayerKeyId
 * @property string $PlayerID
 * @property integer $Index
 * @property integer $GroupDisable
 * @property integer $DevDisable
 * @property integer $GroupID
 *
 * The followings are the available model relations:
 * @property Devclasses $group
 * @property Players $player
 */
class PlayerKeys extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'PlayerKeys';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('PlayerID, Index', 'required'),
			array('Index, GroupDisable, DevDisable, GroupID', 'numerical', 'integerOnly'=>true),
			array('PlayerID', 'length', 'max'=>50),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('PlayerKeyId, PlayerID, Index, GroupDisable, DevDisable, GroupID', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'group' => array(self::BELONGS_TO, 'Devclasses', 'GroupID'),
			'player' => array(self::BELONGS_TO, 'Players', 'PlayerID'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'PlayerKeyId' => 'Player Key',
			'PlayerID' => 'Player',
			'Index' => 'Index',
			'GroupDisable' => 'Group Disable',
			'DevDisable' => 'Dev Disable',
			'GroupID' => 'Group',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('PlayerKeyId',$this->PlayerKeyId);
		$criteria->compare('PlayerID',$this->PlayerID,true);
		$criteria->compare('Index',$this->Index);
		$criteria->compare('GroupDisable',$this->GroupDisable);
		$criteria->compare('DevDisable',$this->DevDisable);
		$criteria->compare('GroupID',$this->GroupID);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return PlayerKeys the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
