<?php

/**
 * This is the model class for table "PlayingSessions".
 *
 * The followings are the available columns in table 'PlayingSessions':
 * @property integer $SessionID
 * @property string $PlayerID
 * @property integer $PlayingFileID
 * @property integer $MultiPort
 * @property integer $CircleLength
 * @property integer $CurrFileProgress
 * @property integer $CurrTotalProgress
 * @property integer $Priority
 * @property integer $Pause
 * @property integer $ScheduleID
 * @property integer $BrdMode
 * @property integer $SesType
 * @property integer $StreamType
 */
class PlayingSessions extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'PlayingSessions';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('SessionID', 'required'),
			array('SessionID, PlayingFileID, MultiPort, CircleLength, CurrFileProgress, CurrTotalProgress, Priority, Pause, ScheduleID, BrdMode, SesType, StreamType', 'numerical', 'integerOnly'=>true),
			array('PlayerID', 'length', 'max'=>50),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('SessionID, PlayerID, PlayingFileID, MultiPort, CircleLength, CurrFileProgress, CurrTotalProgress, Priority, Pause, ScheduleID, BrdMode, SesType, StreamType', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'SessionID' => 'Session',
			'PlayerID' => 'Player',
			'PlayingFileID' => 'Playing File',
			'MultiPort' => 'Multi Port',
			'CircleLength' => 'Circle Length',
			'CurrFileProgress' => 'Curr File Progress',
			'CurrTotalProgress' => 'Curr Total Progress',
			'Priority' => 'Priority',
			'Pause' => 'Pause',
			'ScheduleID' => 'Schedule',
			'BrdMode' => 'Brd Mode',
			'SesType' => 'Ses Type',
			'StreamType' => 'Stream Type',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('SessionID',$this->SessionID);
		$criteria->compare('PlayerID',$this->PlayerID,true);
		$criteria->compare('PlayingFileID',$this->PlayingFileID);
		$criteria->compare('MultiPort',$this->MultiPort);
		$criteria->compare('CircleLength',$this->CircleLength);
		$criteria->compare('CurrFileProgress',$this->CurrFileProgress);
		$criteria->compare('CurrTotalProgress',$this->CurrTotalProgress);
		$criteria->compare('Priority',$this->Priority);
		$criteria->compare('Pause',$this->Pause);
		$criteria->compare('ScheduleID',$this->ScheduleID);
		$criteria->compare('BrdMode',$this->BrdMode);
		$criteria->compare('SesType',$this->SesType);
		$criteria->compare('StreamType',$this->StreamType);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return PlayingSessions the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
