<?php

/**
 * This is the model class for table "ProjectorType".
 *
 * The followings are the available columns in table 'ProjectorType':
 * @property string $Type
 * @property integer $PoweroffDelay
 * @property integer $CheckBit
 * @property integer $StopBit
 * @property integer $DataBit
 * @property integer $BaudRate
 * @property string $CmdOpen
 * @property string $CmdClose
 * @property string $CmdFromPc
 * @property string $CmdFromVideo
 */
class ProjectorType extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'ProjectorType';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('Type, PoweroffDelay, CheckBit, StopBit, DataBit, BaudRate, CmdOpen, CmdClose, CmdFromPc, CmdFromVideo', 'required'),
			array('PoweroffDelay, CheckBit, StopBit, DataBit, BaudRate', 'numerical', 'integerOnly'=>true),
			array('Type', 'length', 'max'=>50),
			array('CmdOpen, CmdClose, CmdFromPc, CmdFromVideo', 'length', 'max'=>255),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('Type, PoweroffDelay, CheckBit, StopBit, DataBit, BaudRate, CmdOpen, CmdClose, CmdFromPc, CmdFromVideo', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'Type' => 'Type',
			'PoweroffDelay' => 'Poweroff Delay',
			'CheckBit' => 'Check Bit',
			'StopBit' => 'Stop Bit',
			'DataBit' => 'Data Bit',
			'BaudRate' => 'Baud Rate',
			'CmdOpen' => 'Cmd Open',
			'CmdClose' => 'Cmd Close',
			'CmdFromPc' => 'Cmd From Pc',
			'CmdFromVideo' => 'Cmd From Video',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('Type',$this->Type,true);
		$criteria->compare('PoweroffDelay',$this->PoweroffDelay);
		$criteria->compare('CheckBit',$this->CheckBit);
		$criteria->compare('StopBit',$this->StopBit);
		$criteria->compare('DataBit',$this->DataBit);
		$criteria->compare('BaudRate',$this->BaudRate);
		$criteria->compare('CmdOpen',$this->CmdOpen,true);
		$criteria->compare('CmdClose',$this->CmdClose,true);
		$criteria->compare('CmdFromPc',$this->CmdFromPc,true);
		$criteria->compare('CmdFromVideo',$this->CmdFromVideo,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return ProjectorType the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
