<?php

/**
 * This is the model class for table "SessionDevice".
 *
 * The followings are the available columns in table 'SessionDevice':
 * @property integer $SessionDevID
 * @property string $DeviceID
 * @property integer $SessionID
 * @property integer $KeyIndex
 * @property integer $DevDisabled
 *
 * The followings are the available model relations:
 * @property Devicelist $device
 * @property Playsessions $session
 */
class SessionDevice extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'SessionDevice';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('DeviceID, SessionID', 'required'),
			array('SessionID, KeyIndex, DevDisabled', 'numerical', 'integerOnly'=>true),
			array('DeviceID', 'length', 'max'=>50),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('SessionDevID, DeviceID, SessionID, KeyIndex, DevDisabled', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'device' => array(self::BELONGS_TO, 'Devicelist', 'DeviceID'),
			'session' => array(self::BELONGS_TO, 'Playsessions', 'SessionID'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'SessionDevID' => 'Session Dev',
			'DeviceID' => 'Device',
			'SessionID' => 'Session',
			'KeyIndex' => 'Key Index',
			'DevDisabled' => 'Dev Disabled',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('SessionDevID',$this->SessionDevID);
		$criteria->compare('DeviceID',$this->DeviceID,true);
		$criteria->compare('SessionID',$this->SessionID);
		$criteria->compare('KeyIndex',$this->KeyIndex);
		$criteria->compare('DevDisabled',$this->DevDisabled);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return SessionDevice the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
