<?php

/**
 * This is the model class for table "Users".
 *
 * The followings are the available columns in table 'Users':
 * @property integer $User_ID
 * @property string $User_Name
 * @property string $User_Desc
 * @property string $Pass_Word
 * @property string $UsbKey
 * @property integer $Priority
 * @property integer $privilege
 * @property string $IcCard
 * @property string $Phone
 * @property integer $ServerSync
 * @property integer $User_Type
 * @property string $User_Sn
 * @property string $User_Expiry
 * @property integer $Mgr_Privilege
 * @property integer $Dev_Privilege
 * @property integer $Create_Type
 * @property integer $IC_Status
 * @property string $Dpm_Sn
 * @property string $Dpm_Name
 *
 * The followings are the available model relations:
 * @property Players $usbKey
 */
class Users extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'Users';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('Priority, privilege, ServerSync, User_Type, Mgr_Privilege, Dev_Privilege, Create_Type, IC_Status', 'numerical', 'integerOnly'=>true),
			array('User_Name, User_Desc', 'length', 'max'=>255),
			array('Pass_Word', 'length', 'max'=>256),
			array('UsbKey, IcCard, Phone', 'length', 'max'=>50),
			array('User_Sn, Dpm_Sn', 'length', 'max'=>20),
			array('Dpm_Name', 'length', 'max'=>100),
			array('User_Expiry', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('User_ID, User_Name, User_Desc, Pass_Word, UsbKey, Priority, privilege, IcCard, Phone, ServerSync, User_Type, User_Sn, User_Expiry, Mgr_Privilege, Dev_Privilege, Create_Type, IC_Status, Dpm_Sn, Dpm_Name', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'usbKey' => array(self::BELONGS_TO, 'Players', 'UsbKey'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'User_ID' => 'User',
			'User_Name' => 'User Name',
			'User_Desc' => 'User Desc',
			'Pass_Word' => 'Pass Word',
			'UsbKey' => 'Usb Key',
			'Priority' => 'Priority',
			'privilege' => 'Privilege',
			'IcCard' => 'Ic Card',
			'Phone' => 'Phone',
			'ServerSync' => 'Server Sync',
			'User_Type' => 'User Type',
			'User_Sn' => 'User Sn',
			'User_Expiry' => 'User Expiry',
			'Mgr_Privilege' => 'Mgr Privilege',
			'Dev_Privilege' => 'Dev Privilege',
			'Create_Type' => 'Create Type',
			'IC_Status' => 'Ic Status',
			'Dpm_Sn' => 'Dpm Sn',
			'Dpm_Name' => 'Dpm Name',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('User_ID',$this->User_ID);
		$criteria->compare('User_Name',$this->User_Name,true);
		$criteria->compare('User_Desc',$this->User_Desc,true);
		$criteria->compare('Pass_Word',$this->Pass_Word,true);
		$criteria->compare('UsbKey',$this->UsbKey,true);
		$criteria->compare('Priority',$this->Priority);
		$criteria->compare('privilege',$this->privilege);
		$criteria->compare('IcCard',$this->IcCard,true);
		$criteria->compare('Phone',$this->Phone,true);
		$criteria->compare('ServerSync',$this->ServerSync);
		$criteria->compare('User_Type',$this->User_Type);
		$criteria->compare('User_Sn',$this->User_Sn,true);
		$criteria->compare('User_Expiry',$this->User_Expiry,true);
		$criteria->compare('Mgr_Privilege',$this->Mgr_Privilege);
		$criteria->compare('Dev_Privilege',$this->Dev_Privilege);
		$criteria->compare('Create_Type',$this->Create_Type);
		$criteria->compare('IC_Status',$this->IC_Status);
		$criteria->compare('Dpm_Sn',$this->Dpm_Sn,true);
		$criteria->compare('Dpm_Name',$this->Dpm_Name,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Users the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
