<?php
class ConfigController extends WebAdminBaseController {
	
	/***********************************************************************/
	/**
	 * 加载配置数据
	 */
	public function actionLoadConfig() {
		
		$owner = $this->GetPostOwnerID ();
		
		if (! is_null ( $owner ) && $owner < 0) {
			//用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '用户需要登陆', null );
			return;
		}
		$config = array ();
		$config ['AirConditioningMode'] = ConfigUtil::LoadAirConditioningMode ();
		$config ['PowerMode'] = ConfigUtil::LoadPowerMode ();
		$config ['RfDevice'] = array();
		$config ['AlternateDate'] = ConfigUtil::LoadAlternateDate ();

		if ($this->JudgeRfDevCtrPrivaliege ( $owner )) {
			$config['RfDevice'] = ExpandUtil::LoadExpandDev ();
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $config );
	}
	
	/**
	 * 获取空调模式 
	 */
	public function actionListAirConditioningMode() {
		
		$owner = $this->GetPostOwnerID ();
		
		if (! is_null ( $owner ) && $owner < 0) {
			//用户无效
			echo CJSON::encode ( array () );
			return;
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', ConfigUtil::LoadAirConditioningMode () );
	}
	
	/**
	 * 获取电源模式 
	 */
	public function actionListPowerMode() {
		
		$owner = $this->GetPostOwnerID ();
		
		if (! is_null ( $owner ) && $owner < 0) {
			//用户无效
			echo CJSON::encode ( array () );
			return;
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', ConfigUtil::LoadPowerMode () );
	}
	
	/**
	 * 获取扩展设备信息
	 */
	public function actionListRfDevices() {
		
		$Out = array ();
		
//		if ($this->JudgeRfDevCtrPrivaliege ( $this->GetPostOwnerID () )) {
			$Out = ExpandUtil::LoadExpandDev ();
//		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $Out );
	}
	
	/**
	 * 加载当前不出时间表
	 */
	public function actionLoadAlternateDate() {
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', array ('AlternateDate' => ConfigUtil::LoadAlternateDate () ) );
	}
	
	/**
	 * 设置语言
	 */
	public function actionSetLanguage() {
		
		if (! isset ( $_POST ['DataParam'] )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$DataParam = CJSON::decode ( $_POST ['DataParam'] );
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		/**
		 * 可以不用区分大小写
		 * uk : 英文
		 * zh_cn：简体中文
		 */
		if (! empty ( $DataParam ['Language'] )) {
			LanguageUtil::saveLanguage($DataParam['Language']);
			
			ToolUtil::writeLog(ToolUtil::WriteOrReadLanguage ( "", LanguageUtil::getUserId(), true ));
			
			echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '修改成功', null );
		} else {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '修改失败', null );
		}
	}
	
	/**
	 * 获取当前语言
	 */
	public function actionGetLanguage() {
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '成功', array ('Language' => ToolUtil::WriteOrReadLanguage ( '', LanguageUtil::getUserId(), true ) ) );
	}
	
	/**
	 * 
	 * 获取系统当前时间
	 */
	public function actionGetCurrentTime() {
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '成功', array ('CurrTime' => time () ) );
	}
	
	/**
	 * 
	 * 获取系统当前时间
	 */
	public function actionGetCurrentTimeStr() {
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '成功', array ('CurrTime' => date('Y-m-d H:i:s') ) );
	}
}