<?php
/*****************************************
 * 系统设置
 ****************************************/
class SysController extends WebAdminBaseController {
	
	///////////////////////////////////////////////////////////////////////////////
	// 用户管理
	////////////////////////////////////////////////////////////////////////////////
	/**
	 * 加载用户列表
	 */
	public function actionListUsers() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$searchKey = $this->GetDataParam ( $DataParam, 'searchKey', "" ); //搜索关键字
		$Start = $this->GetDataParam ( $DataParam, 'Start', - 1, true ); //起始位置
		$Size = $this->GetDataParam ( $DataParam, 'Size', - 1, true ); //获取条数
		$Sort = $this->GetDataParam ( $DataParam, 'Sort', "" ); //排序字段
		$Order = $this->GetDataParam ( $DataParam, 'Order', "" ); //排序方式DESC/ASC
		

		$ParamArr = array ();
		$sql = 'SELECT User_ID, User_Desc, User_Name, User_Sn, User_Type, IcCard, IC_Status, User_Expiry, Dpm_Name, Create_Type FROM Users WHERE User_ID > 0';
		
		//搜索
		if (! empty ( $searchKey )) {
			$searchKey = $DataParam ['searchKey'];
			$sql .= " AND (User_Desc LIKE CONCAT('%', :searchKey, '%') OR User_Sn LIKE CONCAT('%', :searchKey1, '%') OR IcCard LIKE CONCAT('%', :searchKey2, '%'))";
			$ParamArr [':searchKey'] = $searchKey;
			$ParamArr [':searchKey1'] = $searchKey;
			$ParamArr [':searchKey2'] = $searchKey;
		}
		
		//获取总数
		$CountSql = "SELECT COUNT(*) c FROM (" . $sql . ") cc";
		$AllCount = 0;
		$AllCountData = DBMethodUtils::findData ( $CountSql, $ParamArr );
		
		if (! empty ( $AllCountData ['c'] )) {
			$AllCount = $AllCountData ['c'];
		}
		// 排序
		if (! empty ( $Sort ) && ! empty ( $Order )) {
			if ("DESC" == strtoupper ( $Order )) {
				$Order = "DESC";
			} else {
				$Order = "ASC";
			}
			if ('User_Desc' == $Sort) {
				$sql .= " ORDER BY User_Desc " . $Order;
			} else if ('User_Name' == $Sort) {
				$sql .= " ORDER BY User_Name " . $Order;
			} else if ('User_Sn' == $Sort) {
				$sql .= " ORDER BY User_Sn " . $Order;
			} else if ('User_Type' == $Sort) {
				$sql .= " ORDER BY User_Type " . $Order;
			} else if ('IcCard' == $Sort) {
				$sql .= " ORDER BY IcCard " . $Order;
			} else if ('IC_Status' == $Sort) {
				$sql .= " ORDER BY IC_Status " . $Order;
			} else if ('User_Expiry' == $Sort) {
				$sql .= " ORDER BY User_Expiry " . $Order;
			} else if ('Dpm_Name' == $Sort) {
				$sql .= " ORDER BY Dpm_Name " . $Order;
			} else {
				$sql .= " ORDER BY User_ID ASC";
			}
		} else {
			$sql .= " ORDER BY User_ID ASC";
		}
		
		//分页数据
		if (isset ( $_POST ['page'] ) && isset ( $_POST ['rows'] ) && is_numeric ( $_POST ['page'] ) && is_numeric ( $_POST ['rows'] )) {
			$page = $_POST ['page'];
			$size = $_POST ['rows'];
			$start = ($page - 1) * $size;
			$sql = $sql . " LIMIT " . $start . "," . $size;
		} else if (is_numeric ( $Start ) && $Start >= 0 && is_numeric ( $Size ) && $Size > 0) {
			$sql .= " LIMIT " . $Start . "," . $Size;
		}
		$userList = DBMethodUtils::listData ( $sql, $ParamArr );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', array ('Total' => $AllCount, 'Rows' => $userList ) );
	}
	
	/**
	 * 加载一个用户的信息
	 */
	public function actionLoadUserInfo() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		//用户id
		$MemberId = $this->GetDataParam ( $DataParam, "User_ID", "-1" );
		
		//获取用户信息
		$User = Users::model ()->findByPk ( $MemberId );
		
		if (empty ( $User )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$Out = array ();
		$Out ['User_Desc'] = $User ['User_Desc']; //用户姓名输入框：User_Desc
		$Out ['User_Name'] = $User ['User_Name']; //登录名输入框：User_Name
		//		$Out['User_Name'] = $User['User_Name']; //登录密码输入框：Pass_Word(登录名和登录密码只有在管理员可以设置)
		$Out ['User_Sn'] = $User ['User_Sn']; //工号输入框：User_Sn
		$Out ['IcCard'] = $User ['IcCard']; //IC卡号输入框：IC_Card
		$Out ['IC_Status'] = $User ['IC_Status']; //IC卡状态下拉框：正常、挂失或空，IC卡号为空时状态为空。
		$Out ['User_Type'] = $User ['User_Type']; //用户类型下拉框：教师、学生、临聘教师、旁听生四种，User_Type
		$Out ['User_Expiry'] = $User ['User_Expiry']; //过期时间：用户账号过期时间
		$Out ['Dpm_Name'] = $User ['Dpm_Name']; //部门：Dpm_Name
		$Out ['Phone'] = $User ['Phone']; //手机号
		$Out ['Priority'] = $User ['Priority']; //任务优先级
		$Out ['UsbKey'] = $User ['UsbKey']; //呼叫设备id
        $Out ['Mgr_Device_selectAll'] = $User ['Mgr_Privilege']; // 管理设备全选与否
        $Out ['Use_Device_selectAll'] = $User ['Dev_Privilege']; // 使用设备全选与否
		

		//获取用户管理权限
		$privilege = $User ['privilege'];
		$Out ['Privilege_Dev_Ctr'] = PermissionManager::JudgeDevCtrPrivaliege ( $privilege ) ? 1 : 0; //bit0: 多媒体教学设备权限
        $Out ['Privilege_IC_Mgr'] = PermissionManager::JudgeICMgrPrivaliege ( $privilege ) ? 1 : 0; //bit4: IC卡管理权限
        $Out ['Privilege_IpCall'] = PermissionManager::JudgeIpcallPrivaliege ( $privilege ) ? 1 : 0; //bit4: IC卡管理权限
		$Out ['Privilege_Scan'] = PermissionManager::JudgeScanPrivaliege ( $privilege ) ? 1 : 0; //bit5: 浏览权限
		$Out ['Privilege_Broadcast'] = PermissionManager::JudgeBroadcastPrivaliege ( $privilege ) ? 1 : 0; //bit8: 音视频广播权限
		$Out ['Privilege_Rf_Dev'] = PermissionManager::JudgeRfDevCtrPrivaliege ( $privilege ) ? 1 : 0; //bit16: 物联设备管理权限
		$Out ['Mgr_Device_Tree'] = SystemUtil::LoadUserDeviceTree ( $UserID, $MemberId, 1, true ); //管理设备列表
		

		//获取用户使用权限
		$Out ['Use_Device_Tree'] = SystemUtil::LoadUserDeviceTree ( $UserID, $MemberId, 0 , true); //使用设备列表
		

		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $Out );
	}
	
	/**
	 * 更新用户信息
	 */
	public function actionUpdateUserInfo() {
		
		/////////////////////////////////////////////////////////////
		// 1、用户基本信息修改（只有）
		// 2、用户管理权限分配
		// 3、用户管理设备分配
		// 4、用户使用设备分配
		// 5、过期时间只针对临时用户
		/////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$MemberId = $this->GetDataParam ( $DataParam, "User_ID", "-1" ); //用户id
		$IsMgr = $this->GetDataParam ( $DataParam, "IsMgr", "1" ); //管理员还是IC卡用户,1:管理员，0：IC卡用户
		$UserDesc = $this->GetDataParam ( $DataParam, 'User_Desc', '' ); //用户名
		$IcCard = $this->GetDataParam ( $DataParam, 'IcCard', '' ); //IC卡号
		$UserName = $this->GetDataParam ( $DataParam, 'User_Name', '' ); //登录名
		$PassWord = $this->GetDataParam ( $DataParam, 'Pass_Word', '' ); //登录密码
		$Phone = $this->GetDataParam ( $DataParam, 'Phone', '' ); //手机号
		$Priority = $this->GetDataParam ( $DataParam, 'Priority', '' ); //任务优先级
		$UsbKey = $this->GetDataParam ( $DataParam, 'UsbKey', '' ); //呼叫设备id
		$Privilege_Dev_Ctr = $this->GetDataParam ( $DataParam, 'Privilege_Dev_Ctr', '0' ); //bit0: 多媒体教学设备权限, 1：有权限，0：无权限
		$Privilege_IC_Mgr = $this->GetDataParam ( $DataParam, 'Privilege_IC_Mgr', '0' ); //bit4: IC卡管理权限, 1：有权限，0：无权限
        $Privilege_Scan = $this->GetDataParam ( $DataParam, 'Privilege_Scan', '0' ); //bit5: 浏览权限, 1：有权限，0：无权限
        $Privilege_IpCall = $this->GetDataParam ( $DataParam, 'Privilege_IpCall', '0' ); //bit5: 浏览权限, 1：有权限，0：无权限
		$Privilege_Broadcast = $this->GetDataParam ( $DataParam, 'Privilege_Broadcast', '0' ); //bit8: 音视频广播权限, 1：有权限，0：无权限
		$Privilege_Rf_Dev = $this->GetDataParam ( $DataParam, 'Privilege_Rf_Dev', '0' ); //bit16: 物联设备管理权限, 1：有权限，0：无权限
		$MgrDev = $this->GetDataParam ( $DataParam, 'MgrDev', '' ); //可以管理的设备id，用“，”隔开
        $MgrAll = $this->GetDataParam( $DataParam, 'MgrAll', '0'); // 管理设备全选，1：全选，0：非全选
        $UseDev = $this->GetDataParam ( $DataParam, 'UseDev', '' ); //可以使用的设备id，用“，”隔开
        $UseAll = $this->GetDataParam( $DataParam, 'UseAll', '0'); // 使用设备全选，1：全选，0：非全选
		$User_Sn = $this->GetDataParam ( $DataParam, 'User_Sn', '' ); //工号
		$IC_status = $this->GetDataParam ( $DataParam, 'IC_Status', null, true ); //IC卡状态 0：IC卡正常 1：IC卡挂失
		$UserType = $this->GetDataParam ( $DataParam, 'User_Type', '' ); //用户类型 1：学生 2：教师 3：临时人员
		$Dpm_Name = $this->GetDataParam ( $DataParam, 'Dpm_Name', '' ); //部门名称
		$User_Expiry = $this->GetDataParam ( $DataParam, 'User_Expiry', null ); //过期时间，格式：2016-10-11 15:20:30
		

		//获取用户信息
		$User = null;
		$isNew = false;
		
		if (! empty ( $MemberId ) && is_numeric ( $MemberId ) && $MemberId > 0) {
			$User = Users::model ()->findByPk ( $MemberId );
		}
		if (empty ( $User )) {
			$User = new Users ();
			$isNew = true;
		}
		/////////////////////////////////////////////////////////////////////////////////////
		// 1、用户基本信息修改
		// 1-1、非admin用户只有当Create_Type != 1时可以修改用户名
		// 1-2、admin用户当Create_Type = 1是只能修改登录名和密码，Create_Type = 0 是可以全部修改
		//////////////////////////////////////////////////////////////////////////////////////
		$IsAdmin = is_null ( $UserID ) ? true : false; //是否是管理员admin
		$UserCreateType = $User->Create_Type;
		$DeleteMediaBroadcast = false; //是否删除用户的媒体文件和广播任务
		

		if ($IsAdmin && $IsMgr == "1" && ! empty ( $UserName )) { //修改用户名和密码
			if (ASysUtil::JudgeUserName ( $User->User_ID, $UserName )) {
				echo $this->PackResponseData ( ErrcodeUtil::$USER_USER_NAME_EXIST, '登录名已经存在', null );
				return;
			}
		}
		$UsbKey = empty ( $UsbKey ) ? null : $UsbKey; //呼叫设备id
		

		//校验呼叫设备id
		if (! empty ( $UsbKey ) && $User->UsbKey != $UsbKey) {
			$sql = 'SELECT * FROM Players WHERE PlayerID = :PlayerID';
			$Players = DBMethodUtils::findData ( $sql, array (':PlayerID' => $UsbKey ) );
			
			if (! empty ( $Players )) { //呼叫设备不存在
				echo $this->PackResponseData ( ErrcodeUtil::$USER_USB_KEY_NOT_EXIST, '呼叫设备已经存在', null );
				return;
			}
		}
		
		if ($IsAdmin) { //是管理员admin
			if ($IsMgr == "1") { //设置管理员信息
				if ($UserCreateType != 1) { //修改所有信息
					if (empty ( $Priority )) {
						$Priority = 100;
					} else {
						if ($Priority <= 10) {
							$Priority = 10;
						} else if ($Priority >= 100) {
							$Priority = 100;
						}
					}
					$User->Priority = $Priority; //任务优先级
				}
				
				$User->Phone = empty ( $Phone ) ? null : $Phone; //手机号
				$User->User_Desc = $UserDesc; //修改用户名
				$User->IcCard = empty ( $IcCard ) ? null : $IcCard; //IC卡号
				

				$Privilege = 0;
				if ($Privilege_Dev_Ctr == "1") {
					$Privilege = $Privilege | 0x01; //bit0: 多媒体教学设备权限, 1：有权限，0：无权限
				}
				if ($Privilege_IC_Mgr == "1") {
					$Privilege = $Privilege | 0x10; //bit4: IC卡管理权限, 1：有权限，0：无权限
				}
				if ($Privilege_Scan == "1") {
					$Privilege = $Privilege | 0x20; //bit5: 浏览权限, 1：有权限，0：无权限
				}
				if ($Privilege_Broadcast == "1") {
					$Privilege = $Privilege | 0x100; //bit8: 音视频广播权限, 1：有权限，0：无权限
				}
                if ($Privilege_IpCall == "1") {
                    $Privilege = $Privilege | 0x200; //bit9: IP对讲权限, 1：有权限，0：无权限
                }
				if ($Privilege_Rf_Dev == "1") {
					$Privilege = $Privilege | 0x10000; //bit16: 物联设备管理权限, 1：有权限，0：无权限
				}

				$User->privilege = $Privilege; //权限
				

				if ($Privilege_Broadcast != "1") { //没有音视频广播权限，需要删除用户的媒体文件和广播任务
					$DeleteMediaBroadcast = true;
				}
				//校验IC卡是否存在
				if (ASysUtil::JudgeIcCard ( $isNew ? "" : $User->User_ID, $User->IcCard )) { //说明IC卡存在
					echo $this->PackResponseData ( ErrcodeUtil::$USER_ICCARD_EXIST, 'IC卡已经存在', null );
					return;
				}
				if (! in_array ( $IC_status, array (0, 1 ) )) {
					$IC_status = null;
				}
				if (! in_array ( $UserType, array (1, 2, 3 ) )) {
					$UserType = null;
				}
				$User->User_Sn = empty ( $User_Sn ) ? null : $User_Sn; //工号
				$User->IC_Status = is_null ( $IC_status ) ? null : $IC_status; //IC卡状态 0：IC卡正常 1：IC卡挂失
				$User->User_Type = empty ( $UserType ) ? null : $UserType; //用户类型 1：学生 2：教师 3：临时人员
				$User->Dpm_Name = empty ( $Dpm_Name ) ? null : $Dpm_Name; //部门名称
				

				if ($UserType == "3") { //临时人员
					if (empty ( $User_Expiry )) {
						$User->User_Expiry = null; //过期时间
					} else {
						$temp = strtotime ( $User_Expiry );
						
						if (! empty ( $temp ) && $temp > 0) {
							$User->User_Expiry = $User_Expiry; //过期时间
						}
					}
				} else {
					$User->User_Expiry = null; //过期时间
				}
				
				//需要校验工号是否存在
				if (ASysUtil::JudgeUserSn ( $isNew ? "" : $User->User_ID, $User->User_Sn )) { //说明学工号存在
					echo $this->PackResponseData ( ErrcodeUtil::$USER_USER_SN_EXIST, '学工号已经存在', null );
					return;
				}
			} else { //设置IC卡用户，需要清除用户管理信息
				if (! $isNew) {
					//清除登录名和密码
					$User = SystemUtil::updateUserLoginInfo ( $MemberId, "", "" );
				}
				//清除权限
				$User->privilege = 0; //权限
				$UsbKey = null; //呼叫设备id
				$User->Phone = null; //手机号
				$User->User_Name = null; //修改用户名
				

				if ($UserCreateType != 1) { //修改所有信息
					$User->User_Desc = $UserDesc; //修改用户名
					$User->IcCard = empty ( $IcCard ) ? null : $IcCard; //IC卡号
					

					//校验IC卡是否存在
					if (ASysUtil::JudgeIcCard ( $isNew ? "" : $User->User_ID, $User->IcCard )) { //说明IC卡存在
						echo $this->PackResponseData ( ErrcodeUtil::$USER_ICCARD_EXIST, 'IC卡已经存在', null );
						return;
					}
					if (! in_array ( $IC_status, array (0, 1 ) )) {
						$IC_status = null;
					}
					if (! in_array ( $UserType, array (1, 2, 3 ) )) {
						$UserType = null;
					}
					$User->User_Sn = empty ( $User_Sn ) ? null : $User_Sn; //工号
					$User->IC_Status = (is_null ( $IC_status ) || ! in_array ( $IC_status, array (0, 1 ) )) ? null : $IC_status; //IC卡状态 0：IC卡正常 1：IC卡挂失
					$User->User_Type = empty ( $UserType ) ? null : $UserType; //用户类型 1：学生 2：教师 3：临时人员
					$User->Dpm_Name = empty ( $Dpm_Name ) ? null : $Dpm_Name; //部门名称
					

					if ($UserType == "3") { //临时人员
						if (empty ( $User_Expiry )) {
							$User->User_Expiry = null; //过期时间
						} else {
							$temp = strtotime ( $User_Expiry );
							
							if (! empty ( $temp ) && $temp > 0) {
								$User->User_Expiry = $User_Expiry; //过期时间
							}
						}
					} else {
						$User->User_Expiry = null; //过期时间
					}
					
					//需要校验工号是否存在
					if (ASysUtil::JudgeUserSn ( $isNew ? "" : $User->User_ID, $User->User_Sn )) { //说明IC卡存在
						echo $this->PackResponseData ( ErrcodeUtil::$USER_USER_SN_EXIST, 'IC卡已经存在', null );
						return;
					}
				}
			}
		} else { //不是管理员admin
			if ($UserCreateType != 1) { //可以修改用户名
				$User->User_Desc = $UserDesc; //修改用户名
				$User->IcCard = empty ( $IcCard ) ? null : $IcCard; //IC卡号
				

				//校验IC卡是否存在
				if (ASysUtil::JudgeIcCard ( $isNew ? "" : $User->User_ID, $User->IcCard )) { //说明IC卡存在
					echo $this->PackResponseData ( ErrcodeUtil::$USER_ICCARD_EXIST, 'IC卡已经存在', null );
					return;
				}
				if (! in_array ( $IC_status, array (0, 1 ) )) {
					$IC_status = null;
				}
				if (! in_array ( $UserType, array (1, 2, 3 ) )) {
					$UserType = null;
				}
				$User->User_Sn = empty ( $User_Sn ) ? null : $User_Sn; //工号
				$User->IC_Status = (is_null ( $IC_status ) || ! in_array ( $IC_status, array (0, 1 ) )) ? null : $IC_status; //IC卡状态 0：IC卡正常 1：IC卡挂失
				$User->User_Type = empty ( $UserType ) ? null : $UserType; //用户类型 1：学生 2：教师 3：临时人员
				$User->Dpm_Name = empty ( $Dpm_Name ) ? null : $Dpm_Name; //部门名称
				

				if ($UserType == "3") { //临时人员
					if (empty ( $User_Expiry )) {
						$User->User_Expiry = null; //过期时间
					} else {
						$temp = strtotime ( $User_Expiry );
						
						if (! empty ( $temp ) && $temp > 0) {
							$User->User_Expiry = $User_Expiry; //过期时间
						}
					}
				} else {
					$User->User_Expiry = null; //过期时间
				}
				//需要校验工号是否存在
				if (ASysUtil::JudgeUserSn ( $isNew ? "" : $User->User_ID, $User->User_Sn )) { //说明IC卡存在
					echo $this->PackResponseData ( ErrcodeUtil::$USER_USER_SN_EXIST, 'IC卡已经存在', null );
					return;
				}
			}
		}
		if (! empty ( $UsbKey )) { //校验用户是否有广播权限
			if (! PermissionManager::JudgeBroadcastPrivaliege ( $User->privilege )) {
				$UsbKey = null;
			}
		}
		if (! empty ( $UsbKey )) { //校验当前启用的模板
			$sql = "SELECT * FROM  TaskTemplate WHERE idTaskTemplate=(SELECT InfoValue FROM BaseInfo WHERE InfomationID=257)";
			$TemplateInfo = DBMethodUtils::findData ( $sql );
			
			if (empty($TemplateInfo)) {
				echo $this->PackResponseData ( ErrcodeUtil::$USER_TASK_TEMPLATE_NOT_EXIST, '没有启用的任务模板，请启用！', null );
					return;
			}
		}
		$User->UsbKey = $UsbKey;
		$User->ServerSync = 1;
		
		//保存用户信息
		try {
			if (! $User->save ()) {
				//修改失败
				echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '', null );
				return;
			}
		} catch ( Exception $e ) {
			//修改失败
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '', null );
			return;
		}
		$MemberId = $User->User_ID;
		
		if ($IsAdmin && $IsMgr == "1" && ! empty ( $UserName )) { //修改用户名和密码
			$User = SystemUtil::updateUserLoginInfo ( $MemberId, $UserName, $PassWord );
		}
		
		if ($DeleteMediaBroadcast) { //删除用户的媒体文件和广播任务
		//TODO
		//删除用户的媒体文件
		//			$sql = 'DELETE FROM MediaFiles';
		//删除用户的广播任务
		}

        // 管理设备和使用设备权限全选标志
        $selSql = "";
        if($IsAdmin)
            $selSql = "UPDATE Users SET Mgr_Privilege = ". $MgrAll . ", Dev_Privilege = ". $UseAll . " where User_ID = '$MemberId'";
        else
            $selSql = "UPDATE Users SET Dev_Privilege = '$UseAll' where User_ID = '$MemberId'";
        DBMethodUtils::RunSql($selSql);

		// 3、用户管理设备分配(只有管理员有权限)
		if ( $MgrAll == 0 || (!$IsAdmin)) {
            $Type = 1;
            SystemUtil::updateUserDevice ( $MemberId, $MgrDev, $Type );
        }
		// 4、用户使用设备分配（具有管理权限的管理员有权限）
		$ICPer = $this->JudgeICMgrPrivaliege ( $UserID );
        if($IsAdmin || $ICPer) {
            if ( $UseAll == 0 ||  (!$IsAdmin)){ //admin和具有ic卡权限的管理员可以修改
                $Type = 0;
                SystemUtil::updateUserDevice($MemberId, $UseDev, $Type);
            }
        }
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', null );
	}
	
	/**
	 * 用户使用授权（批量） 
	 */
	public function actionUpdateUserUseDev() {
		
		/////////////////////////////////////////////////////////////
		// 1、用户基本信息修改（只有）
		// 2、用户管理权限分配
		// 3、用户管理设备分配
		// 4、用户使用设备分配
		/////////////////////////////////////////////////////////////
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}

        $User = Users::model ()->findByPk ( $UserID );

		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$MemberIds = $this->GetDataParam ( $DataParam, "User_IDs", "-1" ); //用户id，多个用户用，分割
		$UseDev = $this->GetDataParam ( $DataParam, 'UseDev', '' ); //可以使用的设备id，用“，”隔开
        $UseAll = $this->GetDataParam($DataParam, 'Use_All', '0'); //全选与否
		/////////////////////////////////////////////////////////////////////////////////////
		// 1、用户基本信息修改
		// 1-1、非admin用户只有当Create_Type != 1时可以修改用户名
		// 1-2、admin用户当Create_Type = 1是只能修改登录名和密码，Create_Type = 0 是可以全部修改
		//////////////////////////////////////////////////////////////////////////////////////
		$IsAdmin = is_null ( $UserID ) ? true : false; //是否是管理员admin
		// 4、用户使用设备分配（具有管理权限的管理员有权限）
		$ICPer = $this->JudgeICMgrPrivaliege ( $UserID );
		
		if ($ICPer || $IsAdmin) { //admin和具有ic卡权限的管理员可以修改
			$Type = 0;
			
			if (! empty ( $MemberIds )) {
				$tempArr = explode ( ",", $MemberIds );
                $signSql = '';
                foreach ( $tempArr as $item ) {
                    if (empty ( $item )) {
                        continue;
                    }
                    if (($IsAdmin || $User->Mgr_Privilege === 1) && $UseAll === 1){
                        $signSql = "UPDATE Users SET Dev_Privilege = 1 where User_ID = '$item'";
                        DBMethodUtils::RunSql($signSql);
                    }else{
                        $signSql = "UPDATE Users SET Dev_Privilege = 0 where User_ID = '$item'";
                        DBMethodUtils::RunSql($signSql);
                        SystemUtil::updateUserDevice ( $item, $UseDev, $Type );
                    }
                }
			}
		
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', null );
	}
	
	/**
	 * 删除用户（批量）
	 */
	public function actionDeleteUsers() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$MemberIds = $this->GetDataParam ( $DataParam, "User_IDs", "-1" ); //用户id，多个用户用，分割
		/////////////////////////////////////////////////////////////////////////////////////
		// 1、用户基本信息修改
		// 1-1、非admin用户只有当Create_Type != 1时可以修改用户名
		// 1-2、admin用户当Create_Type = 1是只能修改登录名和密码，Create_Type = 0 是可以全部修改
		//////////////////////////////////////////////////////////////////////////////////////
		$IsAdmin = is_null ( $UserID ) ? true : false; //是否是管理员admin
		

		if (! $IsAdmin && ! $this->JudgeICMgrPrivaliege ( $UserID )) { //没有删除权限
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有删除权限', null );
			return;
		}
		if (! empty ( $MemberIds )) {
			$tempIdArr = array ();
			$tempArr = explode ( ",", $MemberIds );
			
			foreach ( $tempArr as $item ) {
				if (! empty ( $item )) {
					$tempIdArr [] = $item;
				}
			}
			
			if (! empty ( $tempIdArr )) {
				//可以删除，Create_Type不为1的用户
				$sql = 'DELETE FROM Users where User_ID IN(' . implode ( $tempIdArr, ',' ) . ') AND Create_Type != 1';
				
				if (! $IsAdmin) {
					$sql .= ' AND (ISNULL(User_Name) OR LENGTH(User_Name) <= 0)';
				}
				DBMethodUtils::RunSql ( $sql );

				if ($IsAdmin) {
					//删除用户管理信息
					$sql = 'UPDATE Users SET User_Name = NULL, Pass_Word = NULL where User_ID IN(' . implode ( $tempIdArr, ',' ) . ') AND Create_Type = 1';
					DBMethodUtils::RunSql ( $sql );
				}

                //可以删除，Create_Type不为1的用户
                $sql = 'select User_Name FROM Users where User_ID IN(' . implode ( $tempIdArr, ',' ) . ')';
                $users = DBMethodUtils::listData( $sql );
                if(count($users) != 0){
                    echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有删除权限', $users );
                    return;
                }
			}
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', null );
	}
	
	/**
	 * 加载授权列表 
	 */
	public function actionLoadUserUseDevices() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}

		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		//用户id
		$MemberId = $this->GetDataParam ( $DataParam, "User_IDs", "-1" );
		
		if (! empty ( $MemberId )) {
			$arr = explode ( ",", $MemberId );
			$count = 0;
			
			foreach ( $arr as $item ) {
				if (! empty ( $item ) && is_numeric ( $item )) {
					$MemberId = $item;
					$count ++;
				}
			}
			if ($count > 1) {
				$MemberId = - 1;
			}
		}
		$Out = array ();
		$Out ['Use_Device_Tree'] = SystemUtil::LoadUserDeviceTree ( $UserID, $MemberId, 0,true ); //使用设备列表

		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $Out );
	}
	
	///////////////////////////////////////////////////////////////////////////////
	// 网络设置
	////////////////////////////////////////////////////////////////////////////////
	/**
	 * 加载网络参数
	 */
	public function actionLoadNetConfig() {
		
		$Out = ASysUtil::LoadNetworkInfo ();
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $Out );
	}
	
	/**
	 * 更新网络参数
	 */
	public function actionUpdateNetConfig() {
		
		/**
		 * Post的参数
		 * {
		 "NetCard":[
		 {
		 "Id":"网卡编号， eth0网卡0，eth1网卡1",
		 "Ip":"Ip地址0",
		 "Mask":"子网掩码",
		 "GetwayIsDefault":"是否是默认网关，1：是，0：不是",
		 "Getway":"网关"
		 }
		 ],
		 "Dns":{
		 "First":"首选DNS",
		 "Second":"备用DNS"
		 }
		 }
		 */
		$DataParam = $this->LoadDataParam ();

		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID )) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有权限！', null );
			return;
		}

		
		//修改网络参数
		if (isset ( $DataParam ['NetCard'] )) { //修改网卡参数
			$GatwayCmd = '';
			
			foreach ( $DataParam ['NetCard'] as $item ) {
				if (empty ( $item ['Id'] ) || empty ( $item ['Ip'] ) || empty ( $item ['Mask'] )) {
					continue;
				}
                $cmd = 'bash idste-eth-cfg ' . $item ['Id'] . ' 0.0.0.0  2>&1';
                exec ( $cmd, $OutPut );

				//命令 idste-eth-cfg [eth] [ip address] [net mask] [gateway]
				$arr = array ();
				$arr [] = $item ['Id'];
				$arr [] = $item ['Ip'];
				$arr [] = $item ['Mask'];
				
				if (isset ( $item ['GetwayIsDefault'] ) && $item ['GetwayIsDefault'] == 1) {
					$arr [] = $item ['Getway'];
					
					$GatwayCmd = 'bash idste-eth-cfg ' . implode ( ' ', $arr ) . '  2>&1';
					continue;
				}
				$cmd = 'bash idste-eth-cfg ' . implode ( ' ', $arr ) . '  2>&1';
				$code = exec ( $cmd, $OutPut );
			}
			
			if (! empty ( $GatwayCmd )) {
				$code = exec ( $GatwayCmd, $OutPut );
			}
		}
		//删除原来的DNS信息
        exec ( 'bash idste-dns-cfg 0.0.0.0' , $OutPut);
		
		//修改DNS
		if (isset ( $DataParam ['Dns'] )) {
			$DNS = $DataParam ['Dns'];
			//命令idste-dns-cfg x.x.x.x [x.x.x.x]
			$temp = array ();
			
			if (! empty ( $DNS ['First'] )) {
				$temp [] = $DNS ['First'];
			}
			if (! empty ( $DNS ['Second'] )) {
				$temp [] = $DNS ['Second'];
			}
			if (! empty ( $temp )) {
				$cmd = 'bash idste-dns-cfg ' . implode ( ' ', $temp ) . '';
				$code = exec ( $cmd, $OutPut );
			}
		}
        $cmd = "sudo /sbin/reboot 2>&1";
        exec($cmd);
        sleep(10);
		$Out = ASysUtil::LoadNetworkInfo ();
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, $this->getStr ( 'appcommon', 'err_msg_modifynetcard_success' ), $Out );
	}
	
	/**
	 * 加载静态路由
	 */
	public function actionListRoute() {
		
		$cmd = 'bash idste-route-cfg 2>&1';
		exec ( $cmd, $Output );
		$Out = array ();
		
		if (! empty ( $Output ) && is_array ( $Output )) {
			foreach ( $Output as $Item ) {
				$arr = explode ( ' ', $Item );
				//GwDevFalg 1:gw，2：dev，GwDevFalg=1则GwDev是Ip，GwDevFlag=2则GwDev是设备eth0或eth1
				$Param = array ('Net' => '', 'NetMask' => '', 'GwDevFalg' => 1, 'GwDev' => '' );
				
				for($i = 0; $i < count ( $arr ); $i ++) {
					if (strtolower ( trim ( $arr [$i] ) ) == '-net') {
						$Param ['Net'] = $arr [$i + 1];
						$i ++;
					} else if (strtolower ( trim ( $arr [$i] ) ) == 'netmask') {
						$Param ['NetMask'] = $arr [$i + 1];
						$i ++;
					} else if (strtolower ( trim ( $arr [$i] ) ) == 'gw') {
						$Param ['GwDevFalg'] = 1;
						$Param ['GwDev'] = $arr [$i + 1];
						$i ++;
					} else if (strtolower ( trim ( $arr [$i] ) ) == 'dev') {
						$Param ['GwDevFalg'] = 2;
						$Param ['GwDev'] = $arr [$i + 1];
						$i ++;
					}
				}
				
				if (! empty ( $Param ['Net'] ) && ! empty ( $Param ['NetMask'] ) && ! empty ( $Param ['GwDev'] )) {
					$Out [] = $Param;
				}
			}
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', $Out );
	}
	
	/**
	 * 增加静态路由
	 */
	public function actionAddRoute() {
		
		/**
		 Post的参数
		 {
		 "Net":"子网号 192.167.1.100",
		 "NetMask":"掩码 255.255.255.0",
		 "GwDevFalg":"1：Ip标志，2：设备标志",
		 "GwDev":"GwDevFalg=1为Ip，GwDevFalg=2为设备号，eth0或eth1"
		 }

		 */
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID )) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有权限！', null );
			return;
		}
		$Net = '';
		if (isset ( $DataParam ['Net'] )) {
			$Net = $DataParam ['Net'];
		}
		$NetMask = '';
		if (isset ( $DataParam ['NetMask'] )) {
			$NetMask = $DataParam ['NetMask'];
		}
		$GwDevFalg = 0;
		if (isset ( $DataParam ['GwDevFalg'] ) && is_numeric ( $DataParam ['GwDevFalg'] )) {
			$GwDevFalg = $DataParam ['GwDevFalg'];
		}
		$GwDev = '';
		
		if (isset ( $DataParam ['GwDev'] )) {
			$GwDev = $DataParam ['GwDev'];
		}
		
		if (empty ( $Net ) || empty ( $NetMask ) || empty ( $GwDev ) || ! in_array ( $GwDevFalg, array (1, 2 ) )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$cmd = 'bash idste-route-cfg add -net ' . $Net . ' netmask ' . $NetMask . ' ' . ($GwDevFalg == 1 ? 'gw' : 'dev') . ' ' . $GwDev . ' 2>&1';
		exec ( $cmd, $Output );
		//		echo $cmd;
		//		print_r($Output);
		//		echo '<br/>';
		//
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '添加完成', null );
		return;
	}
	
	/**
	 * 修改静态路由
	 */
	public function actionModifyRoute() {
		
		/**
		 Post的参数
		 {
		 "OldNet":"子网号 192.167.1.100",
		 "OldNetMask":"掩码 255.255.255.0",
		 "Net":"子网号 192.167.1.100",
		 "NetMask":"掩码 255.255.255.0",
		 "GwDevFalg":"1：Ip标志，2：设备标志",
		 "GwDev":"GwDevFalg=1为Ip，GwDevFalg=2为设备号，eth0或eth1"
		 }
		 */
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID )) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有权限！', null );
			return;
		}
		$OldNet = '';
		if (isset ( $DataParam ['OldNet'] )) {
			$OldNet = $DataParam ['OldNet'];
		}
		$OldNetMask = '';
		if (isset ( $DataParam ['OldNetMask'] )) {
			$OldNetMask = $DataParam ['OldNetMask'];
		}
		$Net = '';
		if (isset ( $DataParam ['Net'] )) {
			$Net = $DataParam ['Net'];
		}
		$NetMask = '';
		if (isset ( $DataParam ['NetMask'] )) {
			$NetMask = $DataParam ['NetMask'];
		}
		$GwDevFalg = 0;
		if (isset ( $DataParam ['GwDevFalg'] ) && is_numeric ( $DataParam ['GwDevFalg'] )) {
			$GwDevFalg = $DataParam ['GwDevFalg'];
		}
		$GwDev = '';
		
		if (isset ( $DataParam ['GwDev'] )) {
			$GwDev = $DataParam ['GwDev'];
		}
		if (empty ( $OldNet ) || empty ( $OldNetMask ) || empty ( $Net ) || empty ( $NetMask ) || empty ( $GwDev ) || ! in_array ( $GwDevFalg, array (1, 2 ) )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		//删除路由
		$cmd = 'bash idste-route-cfg del -net ' . $OldNet . ' netmask ' . $OldNetMask . ' 2>&1';
		exec ( $cmd, $Output );
		//		echo $cmd;
		//		print_r($Output);
		//		echo '<br/>';
		

		//添加路由
		$cmd = 'bash idste-route-cfg add -net ' . $Net . ' netmask ' . $NetMask . ' ' . ($GwDevFalg == 1 ? 'gw' : 'dev') . ' ' . $GwDev . ' 2>&1';
		exec ( $cmd, $Output );
		//		echo $cmd;
		//		print_r($Output);
		//		echo '<br/>';
		

		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '修改完成', null );
		return;
	}
	
	/**
	 * 删除静态路由
	 */
	public function actionDelRoute() {
		
		/**
		 Post的参数
		 {
		 "Net":"子网号 192.167.1.100",
		 "NetMask":"掩码 255.255.255.0",
		 }
		 */
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID )) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有权限！', null );
			return;
		}
		$Net = '';
		if (isset ( $DataParam ['Net'] )) {
			$Net = $DataParam ['Net'];
		}
		$NetMask = '';
		if (isset ( $DataParam ['NetMask'] )) {
			$NetMask = $DataParam ['NetMask'];
		}
		
		if (empty ( $Net ) || empty ( $NetMask )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$cmd = 'bash idste-route-cfg del -net ' . $Net . ' netmask ' . $NetMask;
		exec ( $cmd );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '删除完成', null );
		return;
	}
	
	///////////////////////////////////////////////////////////////////////////////
	// 时间设置
	///////////////////////////////////////////////////////////////////////////////
	/**
	 * 加载系统时间
	 */
	public function actionLoadSysTime() {
		
		exec ( 'date -R', $Output );
		$currentTime = '';
		
		if (! empty ( $Output )) {
			$currentTime = date ( 'Y-m-d H:i:s', strtotime ( $Output [0] ) );
		}
		
		//获取时间服务器
		$TimeServer = '';
		$Output = array ();
		exec ( 'bash ntpconf 2>&1', $Output );
		
		if (! empty ( $Output ) && is_array ( $Output )) {
			$TimeServer = trim ( $Output [0] );
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '', array ('CurrentTime' => $currentTime, 'TimeServer' => $TimeServer ) );
	}
	
	/**
	 * 修改系统时间
	 */
	public function actionUpdateSysTime() {
		/**
		 * Post的参数
		 {
		 "SysTime":"系统时间（不修改则不传），格式：2015-11-30 19:49:51",
		 "TimeServer":"时间服务器，系统时间（不修改则不传）"
			}
		 */
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID )) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有权限！', null );
			return;
		}
		if (is_null ( $UserID )) {
			$UserID = 0;
		}
		$cachedata = CacheUtil::GetCache ( CacheUtil::$USER_CACHE_ID . $UserID );
		
		if (! empty ( $DataParam ['SysTime'] )) { //手动设置系统时间
			if (strtotime ( $DataParam ['SysTime'] ) > 0) {
				$Output = array ();
				$cmd = 'sudo date -s ' . date ( 'm/d/Y', strtotime ( $DataParam ['SysTime'] ) ) . ' 2>&1';
				exec ( $cmd, $Output );
				//				print_r ( $Output );
				//				echo '<br/><br/>';
				

				$Output = array ();
				$cmd = 'sudo date -s ' . date ( 'H:i:s', strtotime ( $DataParam ['SysTime'] ) ) . ' 2>&1';
				exec ( $cmd, $Output );
				//				print_r ( $Output );
				//				echo '<br/><br/>';
				

				$Output = array ();
				$cmd = 'sudo /sbin/hwclock -w 2>&1';
				exec ( $cmd, $Output );
			
		//				print_r ( $Output );
			//				echo '<br/><br/>';
			}
		}
		
		if (! empty ( $DataParam ['TimeServer'] )) { //设置时间服务器
			$Output = array ();
			$cmd = 'bash ntpconf ' . trim ( $DataParam ['TimeServer'] ) . ' 2>&1';
			exec ( $cmd, $Output );
		
		//			print_r ( $Output );
		//			echo '<br/><br/>';
		}
		CacheUtil::SetCache ( CacheUtil::$USER_CACHE_ID . $UserID, $cachedata );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '执行完成', array ('CurrTime' => time () ) );
	}
	///////////////////////////////////////////////////////////////////////////////
	// 系统维护
	///////////////////////////////////////////////////////////////////////////////
	/**
	 * 重启系统
	 */
	public function actionRestartSystem() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID )) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有权限！', null );
			return;
		}
		
		exec ( 'sudo /sbin/reboot 2>&1', $Output );
		//		print_r ( $Output );
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '执行完成', null );
	}
	
	/**
	 * 关机
	 */
	public function actionShutdown() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID )) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有权限！', null );
			return;
		}
		
		exec ( 'sudo /sbin/shutdown -h now 2>&1', $Output );
		//		print_r ( $Output );
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '执行完成', null );
	}
	
	///////////////////////////////////////////////////////////////////////////////
	// 跨网设置
	///////////////////////////////////////////////////////////////////////////////
	/**
	 * 加载跨网设置 
	 */
	public function actionListSubNetwork() {
		
		$sql = "SELECT idSubNetwork, IpAddress, NetMask FROM SubNetwork WHERE idSubNetwork > 0";
		$OutList = DBMethodUtils::listData ( $sql );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", $OutList );
	}
	
	/**
	 * 更新跨网设置
	 */
	public function actionUpdateSubnetwork() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID )) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$sql = "DELETE FROM SubNetwork WHERE idSubNetwork > 0";
		DBMethodUtils::RunSql ( $sql );
		$i = 1;
		
		foreach ( $DataParam as $item ) {
			$IpAddress = $this->GetDataParam ( $item, "IpAddress", "" ); //IP
			$NetMask = $this->GetDataParam ( $item, "NetMask", "" ); //掩码
			

			if (empty ( $IpAddress ) || empty ( $NetMask )) {
				continue;
			}
			$sql = "INSERT INTO SubNetwork(idSubNetwork, IpAddress, NetMask)VALUES(:idSubNetwork,:IpAddress, :NetMask)";
			$code = DBMethodUtils::RunSql ( $sql, array (':idSubNetwork' => $i, ':IpAddress' => $IpAddress, ':NetMask' => $NetMask ) );
			
			if ($code > 0) {
				$i ++;
			}
			if ($i >= 32) {
				break;
			}
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '成功', null );
	}
	
	/**
	 * 编辑跨网设置
	 */
	public function actionEditSubnetwork() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID )) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$idSubNetwork = $this->GetDataParam ( $DataParam, "idSubNetwork", - 1, true ); //IP
		$IpAddress = $this->GetDataParam ( $DataParam, "IpAddress", "" ); //IP
		$NetMask = $this->GetDataParam ( $DataParam, "NetMask", "" ); //掩码
		

		if (empty ( $IpAddress ) || empty ( $NetMask )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		
		if ($idSubNetwork > 0) {
			$sql = "SELECT * FROM SubNetwork WHERE idSubNetwork = :idSubNetwork";
			$Res = DBMethodUtils::listData ( $sql, array (':idSubNetwork' => $idSubNetwork ) );
			
			if (empty ( $Res )) {
				$idSubNetwork = - 1;
			}
		}
		
		if ($idSubNetwork < 0) { //新增
			$sql = "SELECT * FROM SubNetwork WHERE idSubNetwork > 0 ORDER BY idSubNetwork ASC";
			$Res = DBMethodUtils::listData ( $sql );
			
			if (count ( $Res ) >= 32) {
				echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '失败', null );
				return;
			}
			$idSubNetwork = 1;
			
			foreach ( $Res as $item ) {
				if ($item ['idSubNetwork'] == $idSubNetwork) {
					$idSubNetwork ++;
				} else {
					break;
				}
			}
			$sql = "INSERT INTO SubNetwork(idSubNetwork, IpAddress, NetMask)VALUES(:idSubNetwork,:IpAddress, :NetMask)";
			$code = DBMethodUtils::RunSql ( $sql, array (':idSubNetwork' => $idSubNetwork, ':IpAddress' => $IpAddress, ':NetMask' => $NetMask ) );
			
			if ($code > 0) {
				echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '成功', null );
				return;
			}
		} else { //修改
			$sql = "UPDATE SubNetwork SET IpAddress = :IpAddress, NetMask = :NetMask WHERE idSubNetwork = :idSubNetwork";
			$code = DBMethodUtils::RunSql ( $sql, array (':idSubNetwork' => $idSubNetwork, ':IpAddress' => $IpAddress, ':NetMask' => $NetMask ) );
			
			if ($code > 0) {
				echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '成功', null );
				return;
			}
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '失败', null );
	}
	
	/**
	 * 删除跨网设置
	 */
	public function actionDeleteSubnetwork() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID )) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '没有权限！', null );
			return;
		}
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$idSubNetworks = $this->GetDataParam ( $DataParam, "idSubNetworks", "" ); //
		

		if (empty ( $idSubNetworks )) {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '失败', null );
			return;
		}
		$arr = explode ( ",", $idSubNetworks );
		$idArr = array ();
		
		foreach ( $arr as $item ) {
			if (is_numeric ( $item )) {
				$idArr [] = $item;
			}
		}
		if (empty ( $idArr )) {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '失败', null );
			return;
		}
		$sql = "DELETE FROM SubNetwork WHERE idSubNetwork IN(" . implode ( ",", $idArr ) . ")";
		$code = DBMethodUtils::RunSql ( $sql );
		
		if ($code <= 0) {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '失败', null );
			return;
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, '成功', null );
	}
}
