<?php
class SysEventController extends WebAdminBaseController {
	
	/**
	 * 获取事件列表 
	 */
	public function actionList() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$Start = $this->GetDataParam ( $DataParam, 'Start', - 1, true ); //起始位置
		$Size = $this->GetDataParam ( $DataParam, 'Size', - 1, true ); //获取条数
		$Sort = $this->GetDataParam ( $DataParam, 'Sort', "" ); //排序字段
		$Order = $this->GetDataParam ( $DataParam, 'Order', "" ); //排序方式DESC/ASC
		

		//事件名称、开始任务、结束任务、厂商、型号内容
		$sql = "SELECT * FROM (SELECT a.Id, a.Name, a.StartTask, IF(ISNULL(b.SessionName), '', b.SessionName) AS StartTaskName, a.EndTask, IF(ISNULL(c.SessionName), '', c.SessionName) AS EndTaskName, d.Manufacturer, d.Model FROM `Event` a
				LEFT JOIN PlaySessions b ON a.StartTask = b.SessionID
				LEFT JOIN PlaySessions c ON a.EndTask = c.SessionID
				LEFT JOIN EventModel d ON a.Model = d.id) AA";
		
		//获取总数
		$CountSql = "SELECT COUNT(*) c FROM (" . $sql . ") cc";
		$AllCount = 0;
		$AllCountData = DBMethodUtils::findData ( $CountSql );
		
		if (! empty ( $AllCountData ['c'] )) {
			$AllCount = $AllCountData ['c'];
		}
		
		if (! empty ( $Sort ) && ! empty ( $Order )) {
			if ("DESC" == strtoupper ( $Order )) {
				$Order = "DESC";
			} else {
				$Order = "ASC";
			}
			if ("Id" == $Sort) {
				$sql .= " ORDER BY Id " . $Order;
			} else if ("Name" == $Sort) {
				$sql .= " ORDER BY Name " . $Order;
			} else if ("StartTask" == $Sort) {
				$sql .= " ORDER BY StartTask " . $Order;
			} else if ("StartTaskName" == $Sort) {
				$sql .= " ORDER BY StartTaskName " . $Order;
			} else if ("EndTask" == $Sort) {
				$sql .= " ORDER BY EndTask " . $Order;
			} else if ("EndTaskName" == $Sort) {
				$sql .= " ORDER BY EndTaskName " . $Order;
			} else if ("Manufacturer" == $Sort) {
				$sql .= " ORDER BY Manufacturer " . $Order;
			} else if ("Model" == $Sort) {
				$sql .= " ORDER BY Model " . $Order;
			} else {
				$sql .= " ORDER BY Id " . $Order;
			}
		} else {
			$sql .= " ORDER BY Id " . $Order;
		}
		
		if (is_numeric ( $Start ) && $Start >= 0 && is_numeric ( $Size ) && $Size > 0) {
			$sql .= " LIMIT " . $Start . "," . $Size;
		}
		$OutList = DBMethodUtils::listData ( $sql );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", array ('Total' => $AllCount, 'Rows' => $OutList ) );
	}
	
	/**
	 * 获取事件详细
	 */
	public function actionInfo() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$id = $this->GetDataParam ( $DataParam, 'Id', - 1, true ); //事件id
		

		//加载事件数据
		$sql = "SELECT a.Id, a.Name, a.StartTask, c.SessionName AS StartTaskName, a.EndTask, d.SessionName AS EndTaskName, a.Config, a.Model AS ModelId, b.Manufacturer, b.Model FROM Event a 
			LEFT JOIN EventModel b ON a.Model = b.id
			LEFT JOIN PlaySessions c ON a.StartTask = c.SessionID
			LEFT JOIN PlaySessions d ON a.EndTask = d.SessionID
			WHERE a.Id = " . $id;
		$data = DBMethodUtils::findData ( $sql );
		
		if (empty ( $data )) {
			echo $this->PackResponseData ( ErrcodeUtil::$FAILED, '加载失败', null );
			return;
		}
		
		$out = array ();
		
		//公共配置
		$out ['Id'] = $data ['Id']; //事件id
		$out ['Name'] = $data ['Name']; //事件名称输入框，不能为空，最长16个字符或汉字
		$out ['StartTask'] = $data ['StartTask']; //开始任务和结束任务选择框，点击时弹出界面选择*手动任务*，数据库存储任务的ID，前台显示任务名称。
		$out ['EndTask'] = $data ['EndTask']; //开始任务和结束任务选择框，点击时弹出界面选择*手动任务*，数据库存储任务的ID，前台显示任务名称。
		$out ['StartTaskName'] = $data ['StartTaskName']; //开始任务和结束任务选择框，点击时弹出界面选择*手动任务*，数据库存储任务的ID，前台显示任务名称。
		$out ['EndTaskName'] = $data ['EndTaskName']; //开始任务和结束任务选择框，点击时弹出界面选择*手动任务*，数据库存储任务的ID，前台显示任务名称。
		$out ['Manufacturer'] = $data ['Manufacturer']; //厂商下拉框，需要从EventModel表中读出Manufacturer记录后显示在该下拉框
		$out ['Model'] = $data ['Model']; //型号下拉框，显示"厂商"下拉框对应的子型号记录，从EventModel的Model获取
		

		$config = new EventConfigData ();
		$config->Parse ( $data ['Config'] );
		
		//检测配置
		$out ['Ip'] = $config->IP; //IP地址：IPV4地址，需要检测输入IP格式是否正确
		$out ['Port'] = $config->Port; //端口：数字，最大65536
		$out ['IO'] = $config->IoMask; //检测IO口：显示24个单选框，每个单选框上方显示IO口编号，从左到右依次为B1,B2...B24
		$out ['Event'] = $config->IoValue; //事件值：显示24个单选框，单个单选框上方显示一个字符，中文为高、低或X，英文为H、L和X，当单选框选中是上方字符显示H或高，未选中时上方字符显示L或低，事件框变灰时显示X。事件单选框与检测IO口单选框对齐，检测IO单选框未选中时对应事件单选框变灰，否则用户可选；
		

		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "成功", $out );
	}
	
	/**
	 * 编辑事件
	 */
	public function actionEdit() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$Id = $this->GetDataParam ( $DataParam, 'Id', - 1, true ); //事件id
		$Name = $this->GetDataParam ( $DataParam, 'Name', "" ); //事件名称输入框，不能为空，最长16个字符或汉字
		$StartTask = $this->GetDataParam ( $DataParam, 'StartTask', - 1, true ); //开始任务和结束任务选择框，点击时弹出界面选择*手动任务*，数据库存储任务的ID，前台显示任务名称。
		$EndTask = $this->GetDataParam ( $DataParam, 'EndTask', - 1, true ); //开始任务和结束任务选择框，点击时弹出界面选择*手动任务*，数据库存储任务的ID，前台显示任务名称。
		$Model = $this->GetDataParam ( $DataParam, 'Model', - 1, true ); //厂商、型号
		

		//检测配置
		$Ip = $this->GetDataParam ( $DataParam, 'Ip', "" ); //IP地址：IPV4地址，需要检测输入IP格式是否正确
		$Port = $this->GetDataParam ( $DataParam, 'Port', 0, true ); //端口：数字，最大65536
		$IO = $this->GetDataParam ( $DataParam, 'IO', null ); //检测IO口：显示24个单选框，每个单选框上方显示IO口编号，从左到右依次为B1,B2...B24
		$Event = $this->GetDataParam ( $DataParam, 'Event', null ); //事件值：显示24个单选框，单个单选框上方显示一个字符，中文为高、低或X，英文为H、L和X，当单选框选中是上方字符显示H或高，未选中时上方字符显示L或低，事件框变灰时显示X。事件单选框与检测IO口单选框对齐，检测IO单选框未选中时对应事件单选框变灰，否则用户可选；
		

		if (empty ( $Name ) || strlen ( $Name ) > 16) {
			echo $this->PackResponseData ( ErrcodeUtil::$SYS_EVENT_NAME_ERR, '事件名称为空或太长', null );
			return;
		}
		//获取开始任务
		$StartTaskData = ATaskUtil::getHandTask ( $StartTask );
		//获取结束任务
		$EndTaskData = ATaskUtil::getHandTask ( $EndTask );
		
		if (empty ( $StartTaskData ) && empty ( $EndTaskData )) {
			echo $this->PackResponseData ( ErrcodeUtil::$SYS_EVENT_TASK_ERR, '请选择任务', null );
			return;
		}
		//厂商、型号
		$EventModel = EventModel::model ()->findByPk ( $Model );
		
		if (empty ( $EventModel )) {
			echo $this->PackResponseData ( ErrcodeUtil::$SYS_EVENT_MODEL_ERR, '厂商、型号无效', null );
			return;
		}
		//IP地址：IPV4地址，需要检测输入IP格式是否正确
		if (preg_match ( '/^(?:(?:2[0-4][0-9]\.)|(?:25[0-5]\.)|(?:1[0-9][0-9]\.)|(?:[1-9][0-9]\.)|(?:[0-9]\.)){3}(?:(?:2[0-5][0-5])|(?:25[0-5])|(?:1[0-9][0-9])|(?:[1-9][0-9])|(?:[0-9]))$/', $Ip ) <= 0) {
			echo $this->PackResponseData ( ErrcodeUtil::$SYS_EVENT_IP_ERR, 'IP地址无效', null );
			return;
		}
		if ($Port <= 0 || $Port > 65536) {
			echo $this->PackResponseData ( ErrcodeUtil::$SYS_EVENT_PORT_ERR, '端口无效', null );
			return;
		}
		if (! is_array ( $IO ) || count ( $IO ) != 24) {
			echo $this->PackResponseData ( ErrcodeUtil::$SYS_EVENT_IO_ERR, '检测IO口无效', null );
			return;
		}
		if (! is_array ( $Event ) || count ( $Event ) != 24) {
			echo $this->PackResponseData ( ErrcodeUtil::$SYS_EVENT_EVENT_ERR, '事件值口无效', null );
			return;
		}
		$Magic = $EventModel->Magic;
		$IP = $Ip;
		$IoMask = $IO;
		$IoValue = $Event;
		$configModel = new EventConfigData ();
		$config = $configModel->packData ( $Magic, $IP, $Port, $IoMask, $IoValue );
		
		$Event = Event::model ()->findByPk ( $Id );
		
		if (empty ( $Event )) {
			$Event = new Event ();
		}
		$Event->Name = $Name;
		$Event->StartTask = $StartTask;
		$Event->EndTask = $EndTask;
		$Event->Config = $config;
		$Event->Model = $Model;
		// 		$Event->Version = 10;
		

		if ($Event->save ()) {
			echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", null );
			return;
		}
		
		echo $this->PackResponseData ( ErrcodeUtil::$FAILED, "", null );
		return;
	}
	
	/**
	 * 获取手动任务
	 */
	public function actionListTask() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$start = $this->GetDataParam ( $DataParam, 'start', - 1, true ); //起始位置
		$size = $this->GetDataParam ( $DataParam, 'size', - 1, true ); //获取条数
		

		$sql = "SELECT SessionID, SessionName, Priority, CircleLength FROM PlaySessions WHERE SessionType IN(2,9)";
		//获取总数
		$Count = 0;
		$CountSql = 'SELECT COUNT(*) c FROM (' . $sql . ') CC';
		$TempData = DBMethodUtils::findData ( $CountSql );
		
		if (! empty ( $TempData )) {
			$Count = $TempData ['c'];
		}
		//分页数据
		if (is_numeric ( $start ) && $start >= 0 && is_numeric ( $size ) && $size > 0) {
			$sql = $sql . " LIMIT " . $start . "," . $size;
		}
		$out = DBMethodUtils::listData ( $sql );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", array ('Total' => $Count, 'Rows' => $out ) );
	}
	
	/**
	 * 获取厂商、型号 
	 */
	public function actionListModel() {
		
		//获取厂商数据
		$sql = "SELECT Manufacturer FROM EventModel GROUP BY Manufacturer";
		$Manufacturer = DBMethodUtils::listData ( $sql );
		//获取型号数据
		$sql = "SELECT Model FROM EventModel GROUP BY Model";
		$Model = DBMethodUtils::listData ( $sql );
		//获取厂商、型号配置数据
		$sql = "SELECT id, Manufacturer, Model FROM EventModel";
		$EventModel = DBMethodUtils::listData ( $sql );
		
		$out = array ();
		$out ['Manufacturer'] = $Manufacturer;
		$out ['Model'] = $Model;
		$out ['EventModel'] = $EventModel;
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", $out );
	}
	
	/**
	 * 删除事件
	 */
	public function actionRemove() {
		
		$UserID = $this->GetPostOwnerID ();
		
		if (! is_null ( $UserID ) && $UserID < 0) {
			// 用户无效
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NEED_LOGIN, '还没有登陆，请确认！', null );
			return;
		}
		
		if (! is_null ( $UserID )) {
			echo $this->PackResponseData ( ErrcodeUtil::$USER_NO_PERMISSION, '对不起，您没有操作权限！', null );
			return;
		}
		
		//获取DataParam
		$DataParam = $this->LoadDataParam ();
		
		if (is_null ( $DataParam )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		$EventIdList = $this->GetDataParam ( $DataParam, 'EventIdList', array () ); //事件id数组
		

		if (empty ( $EventIdList ) || ! is_array ( $EventIdList )) {
			echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
			return;
		}
		foreach ( $EventIdList as $item ) {
			if (! is_numeric ( $item )) {
				echo $this->PackResponseData ( ErrcodeUtil::$PARAM_ERR, '参数异常', null );
				return;
			}
		}
		//删除数据
		$sql = "DELETE FROM Event WHERE Id IN(" . implode ( $EventIdList, "," ) . ")";
		DBMethodUtils::RunSql ( $sql );
		
		echo $this->PackResponseData ( ErrcodeUtil::$SUCCESS, "", null );
	}

}