<?php
/************************************************************
Config 二进制事件配置记录，用于具体配置事件模块。因为不同厂商的
不同产品采用的信号输入方式、检查对象、事件输出不同，因此需根据具
体检测传感器定制处理线程。
后台程序通过Config的前4个字节生成的magic数字查找线程处理函数。
 Config为二进程内容，采用小端存储，即低字节存储的时数字的低位，
如0xA3C323ED存储在Config中内容为0xED 0x23 0xC3 0xA3。Config
配置示例，如果采用深圳综科智控的ZKD_XIXO-ETH系列输入输出控制卡
进行消防报警检测时，事件Config配置如下:
Magic:0xA3C323ED
IP:192.168.1.122(16字节，不足填0)
Port:10001(2字节)
Reserve:保留(2字节)
IoMask:需要检查的IO口：为1的位为需要检查的位。如0x00000006表示检查bit1和bit2
IoValue:事件发生时IO值，IO口的值与iovalue至少一位相同时事件发生，
	所有位的值与iovalue不同时，事件未发生。如0x00000002表示检查
	bit1位为1或bit2为0时触发事件，bit1为0和bit2为1时事件结束或未触发
 ************************************************************************/
class EventConfigData {
	
	public $Magic; //0xA3C323ED
	public $IP; //192.168.1.122(16字节，不足填0)
	public $Port; //10001(2字节)
	public $Reserve; //保留(2字节)
	public $IoMask; //需要检查的IO口：为1的位为需要检查的位。如0x00000006表示检查bit1和bit2
	public $IoValue; //事件发生时IO值
	

	/**
	 * 解析设备配置
	 * @param 数据库中存储的配置数据
	 */
	public function Parse($Config) {
		
		if (is_null ( $Config ) || trim ( $Config ) == '') {
			return false;
		}
		$arr = unpack ( "C*", $Config );
		
		$pos = 1;
		$this->Magic = hexdec ( dechex ( $arr [$pos + 3] ) . dechex ( $arr [$pos + 2] ) . dechex ( $arr [$pos + 1] ) . dechex ( $arr [$pos] ) );
		$pos += 4;
		$this->IP = ToolUtil::charsetToUTF8 ( ToolUtil::decToStr ( $this->sliceArr ( $arr, $pos, 16 ) ) ); //192.168.1.122(16字节，不足填0)
		$pos += 16;
		$this->Port = hexdec ( dechex ( $arr [$pos + 1] ) . dechex ( $arr [$pos] ) );
		$pos += 2;
		$this->Reserve = hexdec ( dechex ( $arr [$pos + 1] ) . dechex ( $arr [$pos] ) ); //保留(2字节)
		$pos += 2;
		$this->IoMask = array (); //需要检查的IO口：为1的位为需要检查的位。如0x00000006表示检查bit1和bit2
		

		for($i = 0; $i < 3; $i ++) {
			$tmp = $arr [$pos + $i];
			$this->IoMask [$i * 8] = ($tmp & 1) > 0 ? 1 : 0;
			$this->IoMask [$i * 8 + 1] = ($tmp & 2) > 0 ? 1 : 0;
			$this->IoMask [$i * 8 + 2] = ($tmp & 4) > 0 ? 1 : 0;
			$this->IoMask [$i * 8 + 3] = ($tmp & 8) > 0 ? 1 : 0;
			$this->IoMask [$i * 8 + 4] = ($tmp & 16) > 0 ? 1 : 0;
			$this->IoMask [$i * 8 + 5] = ($tmp & 32) > 0 ? 1 : 0;
			$this->IoMask [$i * 8 + 6] = ($tmp & 64) > 0 ? 1 : 0;
			$this->IoMask [$i * 8 + 7] = ($tmp & 128) > 0 ? 1 : 0;
		}
		
		$pos += 4;
		$this->IoValue = array (); //事件发生时IO值
		

		for($i = 0; $i < 3; $i ++) {
			$tmp = $arr [$pos + $i];
			$this->IoValue [$i * 8] = ($tmp & 1) > 0 ? 1 : 0;
			$this->IoValue [$i * 8 + 1] = ($tmp & 2) > 0 ? 1 : 0;
			$this->IoValue [$i * 8 + 2] = ($tmp & 4) > 0 ? 1 : 0;
			$this->IoValue [$i * 8 + 3] = ($tmp & 8) > 0 ? 1 : 0;
			$this->IoValue [$i * 8 + 4] = ($tmp & 16) > 0 ? 1 : 0;
			$this->IoValue [$i * 8 + 5] = ($tmp & 32) > 0 ? 1 : 0;
			$this->IoValue [$i * 8 + 6] = ($tmp & 64) > 0 ? 1 : 0;
			$this->IoValue [$i * 8 + 7] = ($tmp & 128) > 0 ? 1 : 0;
		}
	}
	
	/**
	 * 拆分数组 
	 * @param $arr
	 * @param $pos
	 * @param $size
	 */
	public function sliceArr($arr, $pos, $size) {
		
		$res = array ();
		
		for($i = $pos; $i < $pos + $size; $i ++) {
			if (isset ( $arr [$i] )) {
				$res [] = $arr [$i];
			}
		}
		return $res;
	}
	
	/**
	 * 数组添加
	 * @param $descArr
	 * @param $srcArr
	 * @param $start
	 * @param $length
	 */
	public function arrayAdd($descArr, $srcArr, $start, $length) {
		
		$count = count ( $srcArr );
		
		for($i = 0; $i < $count; $i ++) {
			$descArr ["" . ($start + $i)] = $srcArr [$i];
		}
		
		return $descArr;
	}
	
	/**
	 * 
	 * @param unknown_type $Magic
	 * @param unknown_type $IP
	 * @param unknown_type $Port
	 * @param unknown_type $IoMask
	 * @param unknown_type $IoValue
	 */
	public function packData($Magic, $IP, $Port, $IoMask, $IoValue) {
		
		$arr = array ();
		
		for($i = 0; $i < 32; $i ++) {
			$arr [] = "0";
		}
		$pos = 0;
		
		$MagicTmp = base_convert ( $Magic, 10, 16 );
		
		if (strlen ( $MagicTmp ) <= 0) {
			$arr = $this->arrayAdd ( $arr, array (0 ), $pos + 3, 1 );
			$arr = $this->arrayAdd ( $arr, array (0 ), $pos + 2, 1 );
			$arr = $this->arrayAdd ( $arr, array (0 ), $pos + 1, 1 );
			$arr = $this->arrayAdd ( $arr, array (0 ), $pos + 0, 1 );
		} else if (strlen ( $MagicTmp ) <= 2) {
			$arr = $this->arrayAdd ( $arr, array (hexdec ( $MagicTmp ) ), $pos + 3, 1 );
			$arr = $this->arrayAdd ( $arr, array (0 ), $pos + 2, 1 );
			$arr = $this->arrayAdd ( $arr, array (0 ), $pos + 1, 1 );
			$arr = $this->arrayAdd ( $arr, array (0 ), $pos + 0, 1 );
		} else if (strlen ( $MagicTmp ) <= 4) {
			$arr = $this->arrayAdd ( $arr, array (hexdec ( substr ( $MagicTmp, 0, 2 ) ) ), $pos + 3, 1 );
			$arr = $this->arrayAdd ( $arr, array (hexdec ( substr ( $MagicTmp, 2, 2 ) ) ), $pos + 2, 1 );
			$arr = $this->arrayAdd ( $arr, array (0 ), $pos + 1, 1 );
			$arr = $this->arrayAdd ( $arr, array (0 ), $pos + 0, 1 );
		} else if (strlen ( $MagicTmp ) <= 6) {
			$arr = $this->arrayAdd ( $arr, array (hexdec ( substr ( $MagicTmp, 0, 2 ) ) ), $pos + 3, 1 );
			$arr = $this->arrayAdd ( $arr, array (hexdec ( substr ( $MagicTmp, 2, 2 ) ) ), $pos + 2, 1 );
			$arr = $this->arrayAdd ( $arr, array (hexdec ( substr ( $MagicTmp, 4, 2 ) ) ), $pos + 1, 1 );
			$arr = $this->arrayAdd ( $arr, array (0 ), $pos + 0, 1 );
		} else {
			$arr = $this->arrayAdd ( $arr, array (hexdec ( substr ( $MagicTmp, 0, 2 ) ) ), $pos + 3, 1 );
			$arr = $this->arrayAdd ( $arr, array (hexdec ( substr ( $MagicTmp, 2, 2 ) ) ), $pos + 2, 1 );
			$arr = $this->arrayAdd ( $arr, array (hexdec ( substr ( $MagicTmp, 4, 2 ) ) ), $pos + 1, 1 );
			$arr = $this->arrayAdd ( $arr, array (hexdec ( substr ( $MagicTmp, 6, 2 ) ) ), $pos + 0, 1 );
		}
		$pos += 4;
		$arr = $this->arrayAdd ( $arr, ToolUtil::getb2132Bytes ( $IP ), $pos, 16 );
		$pos += 16;
		$PortTmp = dechex ( $Port );
		
		if (strlen ( $PortTmp ) <= 0) {
			$arr = $this->arrayAdd ( $arr, array (0 ), $pos + 1, 1 );
			$arr = $this->arrayAdd ( $arr, array (0 ), $pos, 1 );
		} else if (strlen ( $PortTmp ) <= 2) {
			$arr = $this->arrayAdd ( $arr, array (hexdec ( $PortTmp ) ), $pos + 1, 1 );
			$arr = $this->arrayAdd ( $arr, array (0 ), $pos, 1 );
		} else {
			$arr = $this->arrayAdd ( $arr, array (hexdec ( substr ( $PortTmp, 0, 2 ) ) ), $pos + 1, 1 );
			$arr = $this->arrayAdd ( $arr, array (hexdec ( substr ( $PortTmp, 2, 2 ) ) ), $pos, 1 );
		}
		
		$pos += 4;
		//每8位处理为一个
		for($i = 0; $i < 3; $i ++) {
			$tmp = 0;
			$tmp |= ($IoMask [$i * 8] == 1) ? 1 : 0;
			$tmp |= ($IoMask [$i * 8 + 1] == 1) ? 2 : 0;
			$tmp |= ($IoMask [$i * 8 + 2] == 1) ? 4 : 0;
			$tmp |= ($IoMask [$i * 8 + 3] == 1) ? 8 : 0;
			$tmp |= ($IoMask [$i * 8 + 4] == 1) ? 16 : 0;
			$tmp |= ($IoMask [$i * 8 + 5] == 1) ? 32 : 0;
			$tmp |= ($IoMask [$i * 8 + 6] == 1) ? 64 : 0;
			$tmp |= ($IoMask [$i * 8 + 7] == 1) ? 128 : 0;
			
			$arr = $this->arrayAdd ( $arr, array ($tmp ), $pos + $i, 1 );
		}
		$pos += 4;
		//每8位处理为一个
		for($i = 0; $i < 3; $i ++) {
			$tmp = 0;
			$tmp |= ($IoValue [$i * 8] == 1) ? 1 : 0;
			$tmp |= ($IoValue [$i * 8 + 1] == 1) ? 2 : 0;
			$tmp |= ($IoValue [$i * 8 + 2] == 1) ? 4 : 0;
			$tmp |= ($IoValue [$i * 8 + 3] == 1) ? 8 : 0;
			$tmp |= ($IoValue [$i * 8 + 4] == 1) ? 16 : 0;
			$tmp |= ($IoValue [$i * 8 + 5] == 1) ? 32 : 0;
			$tmp |= ($IoValue [$i * 8 + 6] == 1) ? 64 : 0;
			$tmp |= ($IoValue [$i * 8 + 7] == 1) ? 128 : 0;
			$arr = $this->arrayAdd ( $arr, array ($tmp ), $pos + $i, 1 );
		}
		$resArr = array ();
		
		foreach ( $arr as $item ) {
			$resArr [] = pack ( "C*", $item );
		}
		$res = implode ( $resArr, '' );
		
		return $res;
	}
}